@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -28,6 +28,10 @@ int FileAttachments::count() const
 
 File FileAttachments::at(int index) const
 {
+    if (index < 0 || index > mFileAttachments.count()) {
+        qCWarning(RUQOLA_LOG) << "Invalid index " << index;
+        return {};
+    }
     return mFileAttachments.at(index);
 }
 
@@ -49,7 +53,7 @@ void FileAttachments::parseFiles(const QJsonObject &fileAttachmentsObj)
             const QJsonObject fileAttachmentObject = current.toObject();
             File m;
             m.parseFile(fileAttachmentObject, true);
-            mFileAttachments.append(m);
+            mFileAttachments.append(std::move(m));
         } else {
             qCWarning(RUQOLA_LOG) << "Problem when parsing file attachment" << current;
         }
