@@ -62,6 +62,8 @@ void OwnUserTest::shouldLoadOwnUser_data()
     ownUser.setEmailNotificationMode(QStringLiteral("mentions"));
     ownUser.setIdleTimeLimit(300);
     ownUser.setEnableAutoAway(true);
+    ownUser.setMessageViewMode(0);
+    ownUser.setDisplayAvatars(false);
     result.setOwnUserPreferences(ownUser);
 
     QTest::addRow("example1") << QStringLiteral("example1") << result;
