@@ -16,7 +16,7 @@ SystemMessagesModelTest::SystemMessagesModelTest(QObject *parent)
 void SystemMessagesModelTest::shouldHaveDefaultValues()
 {
     SystemMessagesModel w;
-    QCOMPARE(w.rowCount(), 31);
+    QCOMPARE(w.rowCount(), 34);
     QVERIFY(w.systemMessagesSelected().isEmpty());
     QStringList lst;
     const int rowCountNb = w.rowCount();
@@ -37,7 +37,7 @@ void SystemMessagesModelTest::shouldHaveDefaultValues()
         QStringLiteral("subscription-role-removed"),
         QStringLiteral("subscription-role-added"),
         QStringLiteral("ru"),
-        QStringLiteral("room_unarchived"),
+        QStringLiteral("room-unarchived"),
         QStringLiteral("room_disabled_encryption"),
         QStringLiteral("enabled_encryption"),
         QStringLiteral("room_changed_privacy"),
@@ -45,7 +45,7 @@ void SystemMessagesModelTest::shouldHaveDefaultValues()
         QStringLiteral("mute_unmute"),
         QStringLiteral("r"),
         QStringLiteral("rm"),
-        QStringLiteral("room_archived"),
+        QStringLiteral("room-archived"),
         QStringLiteral("room_e2e_enabled"),
         QStringLiteral("room_e2e_disabled"),
         QStringLiteral("room-removed-read-only"),
@@ -58,6 +58,9 @@ void SystemMessagesModelTest::shouldHaveDefaultValues()
         QStringLiteral("user-removed-room-from-team"),
         QStringLiteral("user-deleted-room-from-team"),
         QStringLiteral("ujt"),
+        QStringLiteral("removed-user-from-team"),
+        QStringLiteral("added-user-to-team"),
+        QStringLiteral("room_changed_topic"),
     };
 
     for (const QString &r : std::as_const(lst)) {
