@@ -1,11 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "autotranslatelanguages.h"
-
+#include "ruqola_debug.h"
 #include <QJsonArray>
 #include <QJsonObject>
 
@@ -38,6 +38,10 @@ void AutotranslateLanguages::clear()
 
 AutotranslateLanguage AutotranslateLanguages::at(int index) const
 {
+    if (index < 0 || index > mAutotranslateLanguages.count()) {
+        qCWarning(RUQOLA_LOG) << "Invalid index " << index;
+        return {};
+    }
     return mAutotranslateLanguages.at(index);
 }
 
