@@ -27,7 +27,10 @@ class LIBRUQOLACORE_EXPORT DDPClient : public QObject
 {
     Q_OBJECT
 public:
-    enum MessageType { Persistent, Ephemeral };
+    enum MessageType {
+        Persistent,
+        Ephemeral,
+    };
 
     explicit DDPClient(RocketChatAccount *account = nullptr, QObject *parent = nullptr);
     ~DDPClient() override;
@@ -196,6 +199,8 @@ public:
     quint64 setAdminStatus(const QString &userId, bool admin);
     quint64 openRoom(const QString &roomId);
     quint64 getRoomById(const QString &roomId);
+    quint64 bannerDismiss(const QString &bannerId);
+    quint64 licenseGetModules();
 Q_SIGNALS:
     void connecting();
     void connectedChanged();
