@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,8 +25,9 @@ ManageChannels::~ManageChannels() = default;
 ManageChannels::SearchChannelFound ManageChannels::searchOpenChannels(const QString &roomId)
 {
     ManageChannels::SearchChannelFound result = ManageChannels::SearchChannelFound::NoFound;
-    for (int roomIdx = 0, nRooms = mAccount->roomModel()->rowCount(); roomIdx < nRooms; ++roomIdx) {
-        const auto roomModelIndex = mAccount->roomModel()->index(roomIdx, 0);
+    const auto roomModel = mAccount->roomModel();
+    for (int roomIdx = 0, nRooms = roomModel->rowCount(); roomIdx < nRooms; ++roomIdx) {
+        const auto roomModelIndex = roomModel->index(roomIdx, 0);
         const auto identifier = roomModelIndex.data(RoomModel::RoomId).toString();
         if (identifier == roomId) {
             if (roomModelIndex.data(RoomModel::RoomOpen).toBool()) {
@@ -142,6 +143,7 @@ void ManageChannels::openChannel(const QString &roomId, RocketChatAccount::Chann
 
 void ManageChannels::setChannelJoinDone(const RocketChatRestApi::ChannelGroupBaseJob::ChannelGroupInfo &channelInfo)
 {
+    qCDebug(RUQOLA_LOG) << " setChannelJoinDone type:" << channelInfo.channelGroupInfoType << " channelInfo.identifier " << channelInfo.identifier;
     mAccount->ddp()->subscribeRoomMessage(channelInfo.identifier);
     // FIXME room is not added yet...
     switch (channelInfo.channelGroupInfoType) {
