@@ -383,7 +383,7 @@ void Message::setMentions(const QMap<QString, QString> &mentions)
 
 void Message::parseAttachment(const QJsonArray &attachments)
 {
-    mAttachements.clear();
+    mAttachments.clear();
     if (!attachments.isEmpty()) {
         // qDebug() << " void Message::parseAttachment(const QJsonObject &attachments)"<<attachments;
         for (int i = 0; i < attachments.size(); i++) {
@@ -392,7 +392,7 @@ void Message::parseAttachment(const QJsonArray &attachments)
             messageAttachement.parseAttachment(attachment);
             messageAttachement.setAttachmentId(Message::generateAttachmentId(messageId(), i));
             if (messageAttachement.isValid()) {
-                mAttachements.append(messageAttachement);
+                mAttachments.append(messageAttachement);
             }
         }
     }
@@ -404,7 +404,7 @@ bool Message::operator==(const Message &other) const
         && (mUsername == other.username()) && (mName == other.name()) && (mUserId == other.userId()) && (mUpdatedAt == other.updatedAt())
         && (mEditedAt == other.editedAt()) && (mEditedByUsername == other.editedByUsername()) && (mEditedByUserId == other.editedByUserId())
         && (mAlias == other.alias()) && (mAvatar == other.avatar()) && (mSystemMessageType == other.systemMessageType()) && (mGroupable == other.groupable())
-        && (mParseUrls == other.parseUrls()) && (mUrls == other.urls()) && (mAttachements == other.attachments()) && (mMentions == other.mentions())
+        && (mParseUrls == other.parseUrls()) && (mUrls == other.urls()) && (mAttachments == other.attachments()) && (mMentions == other.mentions())
         && (mRole == other.role()) && (mReactions == other.reactions()) && (mUnread == other.unread()) && (mMessagePinned == other.messagePinned())
         && (mMessageStarred == other.messageStarred()) && (mThreadCount == other.threadCount()) && (mThreadLastMessage == other.threadLastMessage())
         && (mDiscussionCount == other.discussionCount()) && (mDiscussionLastMessage == other.discussionLastMessage())
@@ -487,7 +487,8 @@ QString Message::systemMessageText() const
         return i18n("Role \'%3\' was removed to %1 by %2", mText, mUsername, mRole);
     } else if (mSystemMessageType == QLatin1String("e2e")) {
         // TODO need to unencrypt it
-        return i18n("Encrypted message: %1", mText);
+        // return i18n("Encrypted message: %1", mText);
+        return i18n("This message is end-to-end encrypted. To view it, you must enter your encryption key in your account settings.");
     } else if (mSystemMessageType == QLatin1String("discussion-created")) {
         return i18n("Discussion created about \"%1\"", mText);
     } else if (mSystemMessageType == QLatin1String("ut")) {
@@ -516,7 +517,7 @@ QString Message::systemMessageText() const
     } else if (mSystemMessageType == QLatin1String("added-user-to-team")) {
         return i18n("%1 added @%2 to this Team", mUsername, mText);
     } else if (mSystemMessageType == QLatin1String("removed-user-from-team")) {
-        return i18n("Removed %1 from this Team", mUsername);
+        return i18n("%1 removed %2 from this Team", mUsername, mText);
     } else if (mSystemMessageType == QLatin1String("user-converted-to-team")) {
         return i18n("%1 converted #%2 to a Team", mUsername, mText);
     } else if (mSystemMessageType == QLatin1String("user-converted-to-channel")) {
@@ -539,6 +540,12 @@ QString Message::systemMessageText() const
         return i18n("key refreshed successfully"); // Verify
     } else if (mSystemMessageType == QLatin1String("user_requested_otr_key_refresh")) {
         return i18n("Has requested key refresh."); // Verify
+    } else if (mSystemMessageType == QLatin1String("room_changed_topic")) {
+        return i18n("Room topic changed to: %1 by %2", mUsername, mText); // TODO verify
+    } else if (mSystemMessageType == QLatin1String("added-user-to-team")) {
+        return i18n("User added to team: %1 by %2"); // TODO verify
+    } else if (mSystemMessageType == QLatin1String("removed-user-from-team")) {
+        return i18n("User removed to team: %1 by %2"); // TODO verify
     } else {
         qCWarning(RUQOLA_LOG) << "Unknown type for message: type: " << mSystemMessageType << " mText " << mText;
         return i18n("Unknown action!");
@@ -552,12 +559,12 @@ void Message::setMessageType(MessageType messageType)
 
 QVector<MessageAttachment> Message::attachments() const
 {
-    return mAttachements;
+    return mAttachments;
 }
 
-void Message::setAttachements(const QVector<MessageAttachment> &attachments)
+void Message::setAttachments(const QVector<MessageAttachment> &attachments)
 {
-    mAttachements = attachments;
+    mAttachments = attachments;
 }
 
 QVector<MessageUrl> Message::urls() const
@@ -778,7 +785,7 @@ Message Message::fromJSon(const QJsonObject &o, EmojiManager *emojiManager)
         MessageAttachment att = MessageAttachment::fromJson(attachment);
         att.setAttachmentId(Message::generateAttachmentId(message.messageId(), i));
         if (att.isValid()) {
-            message.mAttachements.append(std::move(att));
+            message.mAttachments.append(std::move(att));
         }
     }
     const QJsonArray urlsArray = o.value(QLatin1String("urls")).toArray();
@@ -870,11 +877,11 @@ QByteArray Message::serialize(const Message &message, bool toBinary)
     o[QStringLiteral("messageType")] = QJsonValue::fromVariant(QVariant::fromValue<Message::MessageType>(message.mMessageType));
 
     // Attachments
-    if (!message.mAttachements.isEmpty()) {
+    if (!message.mAttachments.isEmpty()) {
         QJsonArray array;
-        const int nbAttachment = message.mAttachements.count();
+        const int nbAttachment = message.mAttachments.count();
         for (int i = 0; i < nbAttachment; ++i) {
-            array.append(MessageAttachment::serialize(message.mAttachements.at(i)));
+            array.append(MessageAttachment::serialize(message.mAttachments.at(i)));
         }
         o[QStringLiteral("attachments")] = array;
     }
