@@ -259,7 +259,7 @@ QVariant MessageModel::data(const QModelIndex &index, int role) const
     case MessageModel::DateTimeUtc:
         return QDateTime::fromMSecsSinceEpoch(message.timeStamp()).toUTC().toString(Qt::ISODateWithMs);
     case MessageModel::MessageConvertedText:
-        return convertedText(message);
+        return convertedText(message, mSearchText);
     case MessageModel::Timestamp:
         return message.displayTime();
     case MessageModel::UserId:
@@ -283,8 +283,8 @@ QVariant MessageModel::data(const QModelIndex &index, int role) const
     case MessageModel::Attachments: {
         QVariantList lst;
         lst.reserve(message.attachments().count());
-        const auto attachments = message.attachments();
-        for (const MessageAttachment &att : attachments) {
+        const auto attaches = message.attachments();
+        for (const MessageAttachment &att : attaches) {
             lst.append(QVariant::fromValue(att));
         }
         return lst;
@@ -357,6 +357,8 @@ QVariant MessageModel::data(const QModelIndex &index, int role) const
         return message.threadMessageId();
     case MessageModel::ThreadMessagePreview:
         return threadMessagePreview(message.threadMessageId());
+    case MessageModel::ThreadMessageFollowed:
+        return threadMessageFollowed(message.threadMessageId());
     case MessageModel::Groupable:
         return message.groupable();
     case MessageModel::ShowTranslatedMessage:
@@ -393,7 +395,7 @@ QVariant MessageModel::data(const QModelIndex &index, int role) const
     return {};
 }
 
-QString MessageModel::convertedText(const Message &message) const
+QString MessageModel::convertedText(const Message &message, const QString &searchedText) const
 {
     if (message.messageType() == Message::System) {
         return message.systemMessageText();
@@ -409,7 +411,7 @@ QString MessageModel::convertedText(const Message &message) const
         }
         const QString userName = mRocketChatAccount ? mRocketChatAccount->userName() : QString();
         const QStringList highlightWordsLst = mRocketChatAccount ? mRocketChatAccount->highlightWords() : highlightWords;
-        return convertMessageText(message, userName, highlightWordsLst);
+        return convertMessageText(message, userName, highlightWordsLst, searchedText);
     }
 }
 
@@ -435,7 +437,7 @@ bool MessageModel::setData(const QModelIndex &index, const QVariant &value, int
                 break;
             }
         }
-        message.setAttachements(attachments);
+        message.setAttachments(attachments);
         Q_EMIT dataChanged(index, index);
         return true;
     }
@@ -463,20 +465,24 @@ QStringList MessageModel::roomRoles(const QString &userId) const
     return {};
 }
 
-QString MessageModel::convertMessageText(const Message &message, const QString &userName, const QStringList &highlightWords) const
+QString MessageModel::convertMessageText(const Message &message, const QString &userName, const QStringList &highlightWords, const QString &searchedText) const
 {
     QString messageStr = message.text();
-    if (mRocketChatAccount && mRocketChatAccount->hasAutotranslateSupport()) {
-        if (message.showTranslatedMessage() && mRoom && mRoom->autoTranslate() && !mRoom->autoTranslateLanguage().isEmpty()) {
-            const QString messageTranslation = message.messageTranslation().translatedStringFromLanguage(mRoom->autoTranslateLanguage());
-            if (!messageTranslation.isEmpty()) {
-                messageStr = messageTranslation;
+    EmojiManager *emojiManager = nullptr;
+    MessageCache *messageCache = nullptr;
+    if (mRocketChatAccount) {
+        emojiManager = mRocketChatAccount->emojiManager();
+        messageCache = mRocketChatAccount->messageCache();
+        if (mRocketChatAccount->hasAutotranslateSupport()) {
+            if (message.showTranslatedMessage() && mRoom && mRoom->autoTranslate() && !mRoom->autoTranslateLanguage().isEmpty()) {
+                const QString messageTranslation = message.messageTranslation().translatedStringFromLanguage(mRoom->autoTranslateLanguage());
+                if (!messageTranslation.isEmpty()) {
+                    messageStr = messageTranslation;
+                }
             }
         }
     }
 
-    auto emojiManager = mRocketChatAccount ? mRocketChatAccount->emojiManager() : nullptr;
-    auto messageCache = mRocketChatAccount ? mRocketChatAccount->messageCache() : nullptr;
     QString needUpdateMessageId;
     return TextConverter::convertMessageText(messageStr,
                                              userName,
@@ -486,7 +492,8 @@ QString MessageModel::convertMessageText(const Message &message, const QString &
                                              messageCache,
                                              needUpdateMessageId,
                                              message.mentions(),
-                                             message.channels());
+                                             message.channels(),
+                                             searchedText);
 }
 
 void MessageModel::setRoomId(const QString &roomId)
@@ -579,7 +586,7 @@ QString MessageModel::threadMessagePreview(const QString &threadMessageId) const
         auto it = findMessage(threadMessageId);
         if (it != mAllMessages.cend()) {
             const QString userName = mRocketChatAccount ? mRocketChatAccount->userName() : QString();
-            QString str = convertMessageText((*it), userName, mRocketChatAccount ? mRocketChatAccount->highlightWords() : QStringList());
+            QString str = convertMessageText((*it), userName, mRocketChatAccount ? mRocketChatAccount->highlightWords() : QStringList(), QString());
             if (str.length() > 80) {
                 str = str.left(80) + QStringLiteral("...");
             }
@@ -591,6 +598,22 @@ QString MessageModel::threadMessagePreview(const QString &threadMessageId) const
     return {};
 }
 
+bool MessageModel::threadMessageFollowed(const QString &threadMessageId) const
+{
+    if (!threadMessageId.isEmpty()) {
+        auto it = findMessage(threadMessageId);
+        if (it != mAllMessages.cend()) {
+            const QString userId = mRocketChatAccount ? mRocketChatAccount->userId() : QString();
+            if (!userId.isEmpty()) {
+                return (*it).replies().contains(userId);
+            }
+        } else {
+            qCDebug(RUQOLA_LOG) << "Thread message" << threadMessageId << "not found"; // could be a very old one
+        }
+    }
+    return false;
+}
+
 QVector<Message>::iterator MessageModel::findMessage(const QString &messageId)
 {
     return std::find_if(mAllMessages.begin(), mAllMessages.end(), [&](const Message &msg) {
@@ -609,3 +632,13 @@ QString MessageModel::roomId() const
 {
     return mRoomId;
 }
+
+QString MessageModel::searchText() const
+{
+    return mSearchText;
+}
+
+void MessageModel::setSearchText(const QString &searchText)
+{
+    mSearchText = searchText;
+}
