@@ -9,6 +9,7 @@
 #include "accountroomsettings.h"
 #include "attachments/file.h"
 #include "authenticationinfo.h"
+#include "bannerinfo/bannerinfos.h"
 #include "channelgroupbasejob.h"
 #include "commands/runcommandjob.h"
 #include "createchannelteaminfo.h"
@@ -18,9 +19,11 @@
 #include "ddpapi/ddpauthenticationmanager.h"
 #include "inputtextmanager.h"
 #include "libruqolacore_export.h"
+#include "licenses/licensesmanager.h"
 #include "messages/message.h"
 #include "model/listmessagesmodel.h"
 #include "model/roommodel.h"
+#include "notificationinfo.h"
 #include "ownuser/ownuser.h"
 #include "parsemessageurlutils.h"
 #include "permissions/permissionmanager.h"
@@ -229,6 +232,8 @@ public:
     Q_REQUIRED_RESULT QUrl urlForLink(const QString &link) const;
     void setUserStatusChanged(const QJsonArray &array);
 
+    void setShowRoomAvatar(bool checked);
+
     SearchMessageFilterProxyModel *searchMessageFilterProxyModel() const;
     FilesForRoomFilterProxyModel *filesForRoomFilterProxyModel() const;
     ReceiveTypingNotificationManager *receiveTypingNotificationManager() const;
@@ -296,7 +301,9 @@ public:
 
     void sendNotification(const QJsonArray &contents);
     void parseOtr(const QJsonArray &contents);
+
     void setServerVersion(const QString &version);
+    Q_REQUIRED_RESULT QString serverVersion() const;
 
     Q_REQUIRED_RESULT bool needAdaptNewSubscriptionRC60() const;
     Q_REQUIRED_RESULT EmojiManager *emojiManager() const;
@@ -432,7 +439,7 @@ public:
     MessageCache *messageCache() const;
 
     Q_REQUIRED_RESULT bool hideRoles() const;
-    Q_REQUIRED_RESULT bool hideAvatars() const;
+    Q_REQUIRED_RESULT bool displayAvatars() const;
     void roomsAutocomplete(const QString &searchText, const QString &exception);
     Q_REQUIRED_RESULT QString loadMessagesHistory(const QString &roomID, qint64 numberOfMessages);
     Q_REQUIRED_RESULT bool teamEnabled() const;
@@ -490,6 +497,16 @@ public:
     Q_REQUIRED_RESULT int messageMaximumAllowedSize() const;
     Q_REQUIRED_RESULT bool messageAllowConvertLongMessagesToAttachment() const;
 
+    Q_REQUIRED_RESULT bool allowPasswordReset() const;
+    Q_REQUIRED_RESULT const BannerInfos &bannerInfos() const;
+
+    Q_REQUIRED_RESULT bool useRealName() const;
+
+    Q_REQUIRED_RESULT int messageViewMode() const;
+    Q_REQUIRED_RESULT bool hasLicense(const QString &name);
+    void parseLicenses(const QJsonArray &replyArray);
+    // Only for test
+    void setOwnUserPreferences(const OwnUserPreferences &ownUserPreferences);
 Q_SIGNALS:
     void roomRemoved(const QString &roomId);
     void disabledTotpValid(bool checked);
@@ -510,12 +527,11 @@ Q_SIGNALS:
     void added(const QJsonObject &item);
     void changed(const QJsonObject &item);
     void removed(const QJsonObject &item);
-    void notification(const Utils::NotificationInfo &info);
+    void notification(const NotificationInfo &info);
     void fileDownloaded(const QString &filePath, const QUrl &cacheImageUrl);
     void updateNotification(bool hasAlert, int nbUnread, const QString &accountName);
     void missingChannelPassword(const RocketChatRestApi::ChannelGroupBaseJob::ChannelGroupInfo &channelInfo);
     void editingModeChanged();
-    void sortUnreadOnTopChanged();
     void jobFailed(const QString &message, const QString &accountName);
     void switchedRooms();
     void userStatusUpdated(User::PresenceStatus status, const QString &customText, const QString &accountName);
@@ -551,7 +567,10 @@ Q_SIGNALS:
 
     void oauthAppAdded(const QJsonObject &obj);
     void oauthAppUpdated(const QJsonObject &obj);
-    void needUpdateView();
+    void needUpdateMessageView();
+    void needUpdateChannelView();
+    void publicSettingLoaded(const QJsonObject &obj);
+    void bannerInfoChanged();
 
 private:
     Q_DISABLE_COPY(RocketChatAccount)
@@ -609,6 +628,7 @@ private:
     void slotLoadRoles();
     void slotAwayStatusChanged(bool away);
     void slotJobFailed(const QString &str);
+    void checkLicenses();
 
     AccountRoomSettings *const mAccountRoomSettings;
 
@@ -672,7 +692,9 @@ private:
     CustomUserStatuses mCustomUserStatuses;
     PermissionManager mPermissionManager;
     RolesManager mRolesManager;
+    LicensesManager mLicensesManager;
     QStringList mSearchListCompletion;
+    BannerInfos mBannerInfos;
 
     int mDelayReconnect = 100;
     bool mEditingMode = false;
