@@ -26,6 +26,7 @@
 
 void process_publicsettings(const QJsonObject &obj, RocketChatAccount *account)
 {
+    // qDebug() << " obj " << obj;
     account->parsePublicSettings(obj);
 
     // qCDebug(RUQOLA_LOG) << " configs"<<configs;
@@ -34,6 +35,16 @@ void process_publicsettings(const QJsonObject &obj, RocketChatAccount *account)
     }
 }
 
+void process_publicsettings_administrator(const QJsonObject &obj, RocketChatAccount *account)
+{
+    Q_EMIT account->publicSettingLoaded(obj);
+
+    // qCDebug(RUQOLA_LOG) << " configs"<<configs;
+    if (account->ruqolaLogger()) {
+        account->ruqolaLogger()->dataReceived(QByteArrayLiteral("Administrator Public Settings:") + QJsonDocument(obj).toJson());
+    }
+}
+
 void rooms_parsing(const QJsonObject &root, RocketChatAccount *account)
 {
     const QJsonObject obj = root.value(QLatin1String("result")).toObject();
@@ -123,6 +134,7 @@ RocketChatBackend::RocketChatBackend(RocketChatAccount *account, QObject *parent
     connect(mRocketChatAccount, &RocketChatAccount::added, this, &RocketChatBackend::slotAdded);
     connect(mRocketChatAccount, &RocketChatAccount::removed, this, &RocketChatBackend::slotRemoved);
     connect(mRocketChatAccount, &RocketChatAccount::connectedChanged, this, &RocketChatBackend::slotConnectedChanged);
+    connect(mRocketChatAccount, &RocketChatAccount::passwordChanged, this, &RocketChatBackend::tryAutoLogin);
 }
 
 RocketChatBackend::~RocketChatBackend() = default;
@@ -145,6 +157,15 @@ void RocketChatBackend::slotConnectedChanged()
     ddp->method(QStringLiteral("public-settings/get"), QJsonDocument(), process_publicsettings);
 }
 
+void RocketChatBackend::loadPublicSettings()
+{
+    auto ddp = mRocketChatAccount->ddp();
+    if (!ddp->isConnected()) {
+        return;
+    }
+    ddp->method(QStringLiteral("public-settings/get"), QJsonDocument(), process_publicsettings_administrator);
+}
+
 void RocketChatBackend::slotGetServerInfoFailed(bool useDeprecatedVersion)
 {
     if (!useDeprecatedVersion) {
@@ -178,7 +199,7 @@ void RocketChatBackend::processIncomingMessages(const QJsonArray &messages, bool
         if (messageModel) {
             if (!m.threadMessageId().isEmpty()) {
                 mRocketChatAccount->updateThreadMessageList(m);
-                qDebug() << " Update thread message";
+                // qDebug() << " Update thread message";
             }
             if (room) {
                 mMessageLogger->addMessage(mRocketChatAccount->accountName(), room->displayFName(), m);
@@ -232,6 +253,14 @@ void RocketChatBackend::parseServerVersionDone(const QString &version)
 {
     // qCDebug(RUQOLA_LOG) << " void RocketChatBackend::parseServerVersionDone(const QString &version)******************" << version;
     mRocketChatAccount->setServerVersion(version);
+    tryAutoLogin();
+}
+
+void RocketChatBackend::tryAutoLogin()
+{
+    if (mRocketChatAccount->serverVersion().isEmpty() || mRocketChatAccount->password().isEmpty()) {
+        return;
+    }
     mRocketChatAccount->ddp()->login();
 }
 
