@@ -1519,3 +1519,11 @@ void Room::setDirectChannelUserId(const QString &uid)
         Q_EMIT directChannelUserIdChanged();
     }
 }
+
+bool Room::roomIsEmpty() const
+{
+    if (mMessageModel) {
+        return (mMessageModel->rowCount() == 0);
+    }
+    return true;
+}
