@@ -121,6 +121,11 @@ void RuqolaServerConfig::setServerVersion(const QString &version)
     adaptToServerVersion();
 }
 
+QString RuqolaServerConfig::serverVersion() const
+{
+    return mServerVersionStr;
+}
+
 bool RuqolaServerConfig::ruqolaHasSupportForOauthType(AuthenticationManager::OauthType type) const
 {
     return mRuqolaOauthTypes & type;
@@ -185,12 +190,13 @@ void RuqolaServerConfig::setMessageAllowConvertLongMessagesToAttachment(bool new
 
 void RuqolaServerConfig::privateSettingsUpdated(const QJsonArray &updateArray)
 {
-    qWarning() << " privateSettingsUpdated not implemented " << updateArray;
     if (updateArray.count() == 2) {
         if (updateArray.at(0).toString() == QLatin1String("updated")) {
             loadSettings(updateArray.at(1).toObject());
             qDebug() << "Update settings " << *this;
         }
+    } else {
+        qCWarning(RUQOLA_LOG) << "Error in privateSettingsUpdated " << updateArray;
     }
 }
 
@@ -370,6 +376,7 @@ QDebug operator<<(QDebug d, const RuqolaServerConfig &t)
     d << "mUserNameValidation " << t.userNameValidation();
     d << "mMessageMaximumAllowedSize " << t.messageMaximumAllowedSize();
     d << "mMessageAllowConvertLongMessagesToAttachment " << t.messageAllowConvertLongMessagesToAttachment();
+    d << "mUIUseRealName " << t.useRealName();
     return d;
 }
 
@@ -485,11 +492,33 @@ void RuqolaServerConfig::loadSettings(const QJsonObject &currentConfObject)
         setMessageMaximumAllowedSize(value.toInt());
     } else if (id == QLatin1String("Message_AllowConvertLongMessagesToAttachment")) {
         setMessageAllowConvertLongMessagesToAttachment(value.toBool());
+    } else if (id == QLatin1String("UI_Use_Real_Name")) {
+        setUseRealName(value.toBool());
     } else {
         qCDebug(RUQOLA_LOG) << "Other public settings id " << id << value;
     }
 }
 
+bool RuqolaServerConfig::hasEnterpriseSupport() const
+{
+    return mHasEnterpriseSupport;
+}
+
+void RuqolaServerConfig::setHasEnterpriseSupport(bool newHasEnterpriseSupport)
+{
+    mHasEnterpriseSupport = newHasEnterpriseSupport;
+}
+
+bool RuqolaServerConfig::useRealName() const
+{
+    return mUIUseRealName;
+}
+
+void RuqolaServerConfig::setUseRealName(bool newUIUseRealName)
+{
+    mUIUseRealName = newUIUseRealName;
+}
+
 void RuqolaServerConfig::parsePublicSettings(const QJsonObject &obj)
 {
     // qDebug() << " void RuqolaServerConfig::parsePublicSettings(const QJsonObject &obj)" << obj;
