@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,9 +22,10 @@ public:
     Q_REQUIRED_RESULT bool isValid() const override;
     void flush() override;
     void close() override;
-    QAbstractSocket::SocketError error() const override;
+    Q_REQUIRED_RESULT QAbstractSocket::SocketError error() const override;
+    Q_REQUIRED_RESULT QString errorString() const override;
     Q_REQUIRED_RESULT QUrl requestUrl() const override;
-    QWebSocketProtocol::CloseCode closeCode() const override;
+    Q_REQUIRED_RESULT QWebSocketProtocol::CloseCode closeCode() const override;
     Q_REQUIRED_RESULT QString closeReason() const override;
     qint64 sendBinaryMessage(const QByteArray &data) override;
     void ignoreSslErrors() override;
@@ -37,4 +38,3 @@ private:
     RuqolaLogger *const mLogger;
     QWebSocket *const mWebSocket;
 };
-
