@@ -99,7 +99,8 @@ QString generateRichText(const QString &str,
                          const QString &username,
                          const QStringList &highlightWords,
                          const QMap<QString, QString> &mentions,
-                         const QMap<QString, QString> &channels)
+                         const QMap<QString, QString> &channels,
+                         const QString &searchedText)
 {
     QString newStr = markdownToRichText(str);
     static const QRegularExpression regularExpressionAHref(QStringLiteral("(<a href=\'.*\'>|<a href=\".*\">)"));
@@ -146,9 +147,9 @@ QString generateRichText(const QString &str,
         }
     }
 
-    const auto userHighlightForegroundColor = Colors::self().schemeView().foreground(KColorScheme::PositiveText).color().name();
-    const auto userHighlightBackgroundColor = Colors::self().schemeView().background(KColorScheme::PositiveBackground).color().name();
     if (!highlightWords.isEmpty()) {
+        const auto userHighlightForegroundColor = Colors::self().schemeView().foreground(KColorScheme::PositiveText).color().name();
+        const auto userHighlightBackgroundColor = Colors::self().schemeView().background(KColorScheme::PositiveBackground).color().name();
         lstPos.clear();
         QRegularExpressionMatchIterator userIteratorHref = regularExpressionAHref.globalMatch(newStr);
         while (userIteratorHref.hasNext()) {
@@ -185,6 +186,44 @@ QString generateRichText(const QString &str,
             }
         }
     }
+
+    if (!searchedText.isEmpty()) {
+        const auto userHighlightForegroundColor = Colors::self().schemeView().foreground(KColorScheme::NeutralText).color().name();
+        const auto userHighlightBackgroundColor = Colors::self().schemeView().background(KColorScheme::NeutralBackground).color().name();
+        lstPos.clear();
+        QRegularExpressionMatchIterator userIteratorHref = regularExpressionAHref.globalMatch(newStr);
+        while (userIteratorHref.hasNext()) {
+            const QRegularExpressionMatch match = userIteratorHref.next();
+            HrefPos pos;
+            pos.start = match.capturedStart(1);
+            pos.end = match.capturedEnd(1);
+            lstPos.append(std::move(pos));
+        }
+
+        const QRegularExpression exp(QStringLiteral("(\\b%1\\b)").arg(searchedText), QRegularExpression::CaseInsensitiveOption);
+        QRegularExpressionMatchIterator userIterator = exp.globalMatch(newStr);
+        int offset = 0;
+        while (userIterator.hasNext()) {
+            const QRegularExpressionMatch match = userIterator.next();
+            const QString word = match.captured(1);
+            bool inAnUrl = false;
+            const int matchCapturedStart = match.capturedStart(1);
+            for (const HrefPos &hrefPos : lstPos) {
+                if ((matchCapturedStart > hrefPos.start) && (matchCapturedStart < hrefPos.end)) {
+                    inAnUrl = true;
+                    break;
+                }
+            }
+            if (inAnUrl) {
+                continue;
+            }
+            const QString replaceStr =
+                QStringLiteral("<a style=\"color:%2;background-color:%3;\">%1</a>").arg(word, userHighlightForegroundColor, userHighlightBackgroundColor);
+            newStr.replace(matchCapturedStart + offset, word.length(), replaceStr);
+            // We added a new string => increase offset
+            offset += replaceStr.length() - word.length();
+        }
+    }
     static const QRegularExpression regularExpressionUser(QStringLiteral("(^|\\s+)@([\\w._-]+)"), QRegularExpression::UseUnicodePropertiesOption);
     QRegularExpressionMatchIterator userIterator = regularExpressionUser.globalMatch(newStr);
 
@@ -224,7 +263,8 @@ QString TextConverter::convertMessageText(const QString &_str,
                                           MessageCache *messageCache,
                                           QString &needUpdateMessageId,
                                           const QMap<QString, QString> &mentions,
-                                          const QMap<QString, QString> &channels)
+                                          const QMap<QString, QString> &channels,
+                                          const QString &searchedText)
 {
     if (!emojiManager) {
         qCWarning(RUQOLA_TEXTTOHTML_LOG) << "Emojimanager is null";
@@ -253,7 +293,8 @@ QString TextConverter::convertMessageText(const QString &_str,
                                                     messageCache,
                                                     needUpdateMessageId,
                                                     (*it).mentions(),
-                                                    (*it).channels());
+                                                    (*it).channels(),
+                                                    searchedText);
             quotedMessage = Utils::formatQuotedRichText(text);
             str = str.left(startPos - 3) + str.mid(endPos + 1);
         } else {
@@ -269,7 +310,8 @@ QString TextConverter::convertMessageText(const QString &_str,
                                                             messageCache,
                                                             needUpdateMessageId,
                                                             msg->mentions(),
-                                                            msg->channels());
+                                                            msg->channels(),
+                                                            searchedText);
                     quotedMessage = Utils::formatQuotedRichText(text);
                     str = str.left(startPos - 3) + str.mid(endPos + 1);
                 } else {
@@ -335,7 +377,7 @@ QString TextConverter::convertMessageText(const QString &_str,
     };
 
     auto addTextChunk = [&](const QString &chunk) {
-        auto htmlChunk = generateRichText(chunk, userName, highlightWords, mentions, channels);
+        auto htmlChunk = generateRichText(chunk, userName, highlightWords, mentions, channels, searchedText);
         if (emojiManager) {
             emojiManager->replaceEmojis(&htmlChunk);
         }
