@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -24,6 +24,7 @@ void AdminRoomsJobTest::shouldHaveDefaultValue()
     QVERIFY(job.requireHttpAuthentication());
     QVERIFY(!job.restApiLogger());
     QVERIFY(job.hasQueryParameterSupport());
+    QVERIFY(!job.requireTwoFactorAuthentication());
 }
 
 void AdminRoomsJobTest::shouldGenerateRequest()
@@ -39,4 +40,14 @@ void AdminRoomsJobTest::shouldGenerateRequest()
     job.setRoomsAdminInfo(info);
     request = job.request();
     QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/rooms.adminRooms?filter=%1").arg(info.filter)));
+
+    info.searchType = AdminRoomsJob::AdminRoomSearchType::Private;
+    job.setRoomsAdminInfo(info);
+    request = job.request();
+    QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/rooms.adminRooms?filter=%1&types[]=p").arg(info.filter)));
+
+    info.searchType |= AdminRoomsJob::AdminRoomSearchType::OmniChannel;
+    job.setRoomsAdminInfo(info);
+    request = job.request();
+    QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/rooms.adminRooms?filter=%1&types[]=p&types[]=l").arg(info.filter)));
 }
