@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,6 +22,7 @@ void UsersUpdateJobTest::shouldHaveDefaultValue()
     verifyDefaultValue(&job);
     QVERIFY(job.requireHttpAuthentication());
     QVERIFY(!job.hasQueryParameterSupport());
+    QVERIFY(job.requireTwoFactorAuthentication());
 }
 
 void UsersUpdateJobTest::shouldGenerateRequest()
@@ -39,7 +40,7 @@ void UsersUpdateJobTest::shouldGenerateJson()
     UpdateUserInfo info;
     info.mTypeInfo = CreateUpdateUserInfo::Update;
 
-    QString mUserId = QStringLiteral("foo");
+    const QString mUserId = QStringLiteral("foo");
 
     const QString mEmail = QStringLiteral("bla@kde.org");
     const QString mName = QStringLiteral("name_bla");
@@ -47,10 +48,8 @@ void UsersUpdateJobTest::shouldGenerateJson()
     const QString mPassword = QStringLiteral("password_bla");
 
     job.setUpdateInfo(info);
-    // QVERIFY(!job.canStart());
     info.mUserId = mUserId;
     job.setUpdateInfo(info);
-    // QVERIFY(job.canStart());
 
     info.mEmail = mEmail;
     info.mName = mName;
@@ -60,8 +59,8 @@ void UsersUpdateJobTest::shouldGenerateJson()
     QCOMPARE(
         job.json().toJson(QJsonDocument::Compact),
         QStringLiteral(
-            R"({"data":{"email":"%1","name":"%2","password":"%4","requirePasswordChange":false,"sendWelcomeEmail":false,"setRandomPassword":false,"username":"%3","verified":false}})")
-            .arg(mEmail, mName, mUserName, mPassword)
+            R"({"data":{"email":"%1","name":"%2","password":"%4","requirePasswordChange":false,"sendWelcomeEmail":false,"setRandomPassword":false,"username":"%3","verified":false},"userId":"%5"})")
+            .arg(mEmail, mName, mUserName, mPassword, mUserId)
             .toLatin1());
 }
 
@@ -93,5 +92,11 @@ void UsersUpdateJobTest::shouldNotStarting()
 
     info.mEmail = QStringLiteral("emil");
     job.setUpdateInfo(info);
+    QVERIFY(!job.canStart());
+
+    job.setAuthCode(QStringLiteral("bla"));
+    QVERIFY(!job.canStart());
+
+    job.setAuthMethod(QStringLiteral("method"));
     QVERIFY(job.canStart());
 }
