@@ -8,6 +8,7 @@
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
+#include <KLocalizedString>
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QNetworkReply>
@@ -93,3 +94,12 @@ QNetworkRequest ChannelRemoveModeratorJob::request() const
     addRequestAttribute(request);
     return request;
 }
+
+QString ChannelRemoveModeratorJob::errorMessage(const QString &str, const QJsonObject &detail)
+{
+    if (str == QLatin1String("error-user-not-moderator")) {
+        return i18n("User is not a moderator.");
+    }
+
+    return RestApiAbstractJob::errorMessage(str, detail);
+}
