@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
-#include "librestapi_private_export.h"
+#include "librocketchatrestapi-qt5_export.h"
 #include "restapiabstractjob.h"
 namespace RocketChatRestApi
 {
-class LIBROCKETCHATRESTAPI_QT5_TESTS_EXPORT FollowMessageJob : public RestApiAbstractJob
+class LIBROCKETCHATRESTAPI_QT5_EXPORT FollowMessageJob : public RestApiAbstractJob
 {
     Q_OBJECT
 public:
