@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,6 +7,7 @@
 #pragma once
 
 #include "librestapi_private_export.h"
+#include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QObject>
 #include <QPointer>
@@ -82,9 +83,13 @@ public:
 
     virtual bool start() = 0;
     virtual bool requireHttpAuthentication() const = 0;
+    virtual bool requireTwoFactorAuthentication() const;
 
     virtual bool hasQueryParameterSupport() const;
 
+    void setEnforcePasswordFallback(bool enforce);
+    Q_REQUIRED_RESULT bool enforcePasswordFallback() const;
+
     RocketChatRestApi::AbstractLogger *restApiLogger() const;
     void setRestApiLogger(RocketChatRestApi::AbstractLogger *restApiLogger);
 
@@ -101,6 +106,13 @@ public:
 
     void addQueryParameter(QUrlQuery &urlQuery) const;
     void addRequestAttribute(QNetworkRequest &request, bool addContentTypeHeader = true) const;
+
+    Q_REQUIRED_RESULT const QString &authMethod() const;
+    void setAuthMethod(const QString &newAuthMethod);
+
+    Q_REQUIRED_RESULT const QString &authCode() const;
+    void setAuthCode(const QString &newAuthCode);
+
 Q_SIGNALS:
     void failed(const QString &str);
 
@@ -139,9 +151,14 @@ protected Q_SLOTS:
     }
 
 private:
+    void genericResponseHandler(void (RestApiAbstractJob::*func)(const QJsonDocument &replyJson));
+
     QueryParameters mQueryParameters;
     QString mAuthToken;
     QString mUserId;
+    QString mAuthMethod;
+    QString mAuthCode;
+    bool mEnforcePasswordFallBack = true;
     QNetworkAccessManager *mNetworkAccessManager = nullptr;
     RocketChatRestApi::AbstractLogger *mRestApiLogger = nullptr;
 };
