@@ -282,7 +282,7 @@ QString RestApiUtil::restUrl(RestApiUtil::RestApiUrlType type)
     case RestApiUtil::RestApiUrlType::SettingsPublic:
         return QStringLiteral("settings.public");
     case RestApiUtil::RestApiUrlType::UpdateAdminSettings:
-        return QStringLiteral("settings/");
+        return QStringLiteral("settings");
     case RestApiUtil::RestApiUrlType::RoomsUpload:
         return QStringLiteral("rooms.upload");
     case RestApiUtil::RestApiUrlType::RoomsSaveNotification:
@@ -504,6 +504,27 @@ QString RestApiUtil::restUrl(RestApiUtil::RestApiUrlType type)
         return QStringLiteral("licenses.maxActiveUsers");
     case RestApiUtil::RestApiUrlType::LicensesAdd:
         return QStringLiteral("licenses.add");
+    case RestApiUtil::RestApiUrlType::LicensesIsEntreprise:
+        return QStringLiteral("licenses.isEnterprise");
+
+    case RestApiUtil::RestApiUrlType::BannersDismiss:
+        return QStringLiteral("banners.dismiss");
+    case RestApiUtil::RestApiUrlType::Banners:
+        return QStringLiteral("banners");
+
+    // RC 5.0
+    case RestApiUtil::RestApiUrlType::SessionsList:
+        return QStringLiteral("sessions/list");
+    case RestApiUtil::RestApiUrlType::SessionsInfo:
+        return QStringLiteral("sessions/info");
+    case RestApiUtil::RestApiUrlType::SessionsListAll:
+        return QStringLiteral("sessions/list.all");
+    case RestApiUtil::RestApiUrlType::SessionsLogoutMe:
+        return QStringLiteral("sessions/logout.me");
+    case RestApiUtil::RestApiUrlType::SessionsLogout:
+        return QStringLiteral("sessions/logout");
+    case RestApiUtil::RestApiUrlType::SessionsInfoAdmin:
+        return QStringLiteral("sessions/info.admin");
     }
     qCWarning(ROCKETCHATQTRESTAPI_LOG) << "Unknown RestApiUtil::RestApiUrlType " << static_cast<int>(type);
     return {};
