@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -23,6 +23,7 @@ public:
         QString messageText;
         QString threadMessageId;
         QUrl filenameUrl;
+        bool deleteTemporaryFile = false;
         Q_REQUIRED_RESULT bool isValid() const;
     };
 
@@ -44,8 +45,11 @@ public:
     Q_REQUIRED_RESULT UploadFileInfo uploadFileInfo() const;
     void setUploadFileInfo(const UploadFileInfo &uploadFileInfo);
 
+    void abort();
+
 Q_SIGNALS:
     void uploadProgress(const RocketChatRestApi::UploadFileJob::UploadStatusInfo &info);
+    void uploadFinished();
 
 private:
     Q_DISABLE_COPY(UploadFileJob)
