@@ -8,6 +8,8 @@
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
 
+#include <KLocalizedString>
+
 #include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
@@ -99,17 +101,44 @@ QJsonDocument UsersSetPreferencesJob::json() const
     if (!mUsersSetPreferencesInfo.emailNotificationMode.isEmpty()) {
         dataObj[QLatin1String("emailNotificationMode")] = mUsersSetPreferencesInfo.emailNotificationMode;
     }
+    if (mUsersSetPreferencesInfo.messageViewMode != -1) {
+        dataObj[QLatin1String("messageViewMode")] = mUsersSetPreferencesInfo.messageViewMode;
+    }
+    if (!mUsersSetPreferencesInfo.highlights.isEmpty()) {
+        dataObj[QLatin1String("highlights")] = QJsonArray::fromStringList(mUsersSetPreferencesInfo.highlights);
+    }
 
-    dataObj[QLatin1String("useEmojis")] = mUsersSetPreferencesInfo.useEmoji;
-    dataObj[QLatin1String("convertAsciiEmoji")] = mUsersSetPreferencesInfo.convertAsciiToEmoji;
-    dataObj[QLatin1String("highlights")] = QJsonArray::fromStringList(mUsersSetPreferencesInfo.highlights);
-    dataObj[QLatin1String("hideRoles")] = mUsersSetPreferencesInfo.hideRoles;
-    dataObj[QLatin1String("hideAvatars")] = mUsersSetPreferencesInfo.hideAvatars;
+    if (mUsersSetPreferencesInfo.useEmoji != UsersSetPreferencesInfo::Unknown) {
+        dataObj[QLatin1String("useEmojis")] = UsersSetPreferencesInfo::convertToBool(mUsersSetPreferencesInfo.useEmoji);
+    }
+    if (mUsersSetPreferencesInfo.convertAsciiToEmoji != UsersSetPreferencesInfo::Unknown) {
+        dataObj[QLatin1String("convertAsciiEmoji")] = UsersSetPreferencesInfo::convertToBool(mUsersSetPreferencesInfo.convertAsciiToEmoji);
+    }
+    if (mUsersSetPreferencesInfo.hideRoles != UsersSetPreferencesInfo::Unknown) {
+        dataObj[QLatin1String("hideRoles")] = UsersSetPreferencesInfo::convertToBool(mUsersSetPreferencesInfo.hideRoles);
+    }
+    if (mUsersSetPreferencesInfo.displayAvatars != UsersSetPreferencesInfo::Unknown) {
+        dataObj[QLatin1String("displayAvatars")] = UsersSetPreferencesInfo::convertToBool(mUsersSetPreferencesInfo.displayAvatars);
+    }
+    if (mUsersSetPreferencesInfo.sidebarDisplayAvatar != UsersSetPreferencesInfo::Unknown) {
+        dataObj[QLatin1String("sidebarDisplayAvatar")] = UsersSetPreferencesInfo::convertToBool(mUsersSetPreferencesInfo.sidebarDisplayAvatar);
+    }
+    if (mUsersSetPreferencesInfo.sidebarShowUnread != UsersSetPreferencesInfo::Unknown) {
+        dataObj[QLatin1String("sidebarShowUnread")] = UsersSetPreferencesInfo::convertToBool(mUsersSetPreferencesInfo.sidebarShowUnread);
+    }
     jsonObj[QLatin1String("data")] = dataObj;
     const QJsonDocument postData = QJsonDocument(jsonObj);
     return postData;
 }
 
+QString UsersSetPreferencesJob::errorMessage(const QString &str, const QJsonObject &details)
+{
+    if (str == QLatin1String("invalid-params")) {
+        return i18n("Invalid parameters");
+    }
+    return RestApiAbstractJob::errorMessage(str, details);
+}
+
 QDebug operator<<(QDebug d, const RocketChatRestApi::UsersSetPreferencesJob::UsersSetPreferencesInfo &t)
 {
     d << "userId : " << t.userId;
@@ -123,7 +152,9 @@ QDebug operator<<(QDebug d, const RocketChatRestApi::UsersSetPreferencesJob::Use
     d << "useEmoji: " << t.useEmoji;
     d << "convertAsciiToEmoji: " << t.convertAsciiToEmoji;
     d << "hideRoles: " << t.hideRoles;
-    d << "hideAvatars: " << t.hideAvatars;
+    d << "displayAvatars: " << t.displayAvatars;
+    d << "messageViewMode: " << t.messageViewMode;
+    d << "sidebarShowUnread: " << t.sidebarShowUnread;
     return d;
 }
 
@@ -131,3 +162,21 @@ bool UsersSetPreferencesJob::UsersSetPreferencesInfo::isValid() const
 {
     return !userId.isEmpty();
 }
+
+bool UsersSetPreferencesJob::UsersSetPreferencesInfo::convertToBool(State state)
+{
+    switch (state) {
+    case Unknown:
+        return false;
+    case Checked:
+        return true;
+    case Unchecked:
+        return false;
+    }
+    return false;
+}
+
+UsersSetPreferencesJob::UsersSetPreferencesInfo::State UsersSetPreferencesJob::UsersSetPreferencesInfo::convertToState(bool checked)
+{
+    return checked ? UsersSetPreferencesJob::UsersSetPreferencesInfo::Checked : UsersSetPreferencesJob::UsersSetPreferencesInfo::Unchecked;
+}
