@@ -7,7 +7,7 @@
 #include "administratorcustomsoundswidgettest.h"
 #include "administratordialog/customsounds/administratorcustomsoundswidget.h"
 #include "model/admincustomsoundmodel.h"
-#include "model/directorybasefilterproxymodel.h"
+#include "model/searchtreebasefilterproxymodel.h"
 #include <KTreeWidgetSearchLineWidget>
 #include <QTest>
 #include <QVBoxLayout>
@@ -26,6 +26,6 @@ void AdministratorCustomSoundsWidgetTest::shouldHaveDefaultValues()
     auto mModel = w.findChild<AdminCustomSoundModel *>(QStringLiteral("mAdminCustomSoundModel"));
     QVERIFY(mModel);
 
-    auto mProxyModelModel = w.findChild<DirectoryBaseFilterProxyModel *>(QStringLiteral("mCustomSoundProxyModel"));
+    auto mProxyModelModel = w.findChild<SearchTreeBaseFilterProxyModel *>(QStringLiteral("mCustomSoundProxyModel"));
     QVERIFY(mProxyModelModel);
 }
