@@ -7,6 +7,7 @@
 #include "channellistview.h"
 #include "channellistdelegate.h"
 #include "connection.h"
+#include "dialogs/configurenotificationdialog.h"
 #include "model/roomfilterproxymodel.h"
 #include "model/roomlistheadingsproxymodel.h"
 #include "rocketchataccount.h"
@@ -47,11 +48,15 @@ ChannelListView::~ChannelListView() = default;
 
 void ChannelListView::setCurrentRocketChatAccount(RocketChatAccount *currentRocketChatAccount)
 {
-    mCurrentRocketChatAccount = currentRocketChatAccount;
     if (mCurrentRocketChatAccount) {
         disconnect(mCurrentRocketChatAccount, &RocketChatAccount::roomRemoved, this, &ChannelListView::slotRoomRemoved);
+        disconnect(mUpdateChannelViewConnect);
     }
+    mCurrentRocketChatAccount = currentRocketChatAccount;
     connect(mCurrentRocketChatAccount, &RocketChatAccount::roomRemoved, this, &ChannelListView::slotRoomRemoved);
+    mUpdateChannelViewConnect = connect(mCurrentRocketChatAccount, &RocketChatAccount::needUpdateChannelView, this, [this]() {
+        filterModel()->invalidate();
+    });
     mChannelListDelegate->setCurrentRocketChatAccount(currentRocketChatAccount);
 }
 
@@ -112,10 +117,9 @@ void ChannelListView::contextMenuEvent(QContextMenuEvent *event)
     });
 
     if (roomType == Room::RoomType::Channel || roomType == Room::RoomType::Private) { // Not direct channel
-        auto *rcAccount = Ruqola::self()->rocketChatAccount();
-        if (rcAccount->teamEnabled()) {
-            const QString roomId = index.data(RoomModel::RoomId).toString();
-            Room *room = rcAccount->room(roomId);
+        const QString roomId = index.data(RoomModel::RoomId).toString();
+        Room *room = mCurrentRocketChatAccount->room(roomId);
+        if (mCurrentRocketChatAccount->teamEnabled()) {
             if (room) {
                 const bool mainTeam = index.data(RoomModel::RoomTeamIsMain).toBool();
                 if (!mainTeam) {
@@ -153,6 +157,15 @@ void ChannelListView::contextMenuEvent(QContextMenuEvent *event)
         menu.addSeparator();
         menu.addAction(hideChannel);
 
+        if (room) {
+            menu.addSeparator();
+            auto configureNotificationChannel =
+                new QAction(QIcon::fromTheme(QStringLiteral("preferences-desktop-notification")), i18n("Configure Notification..."), &menu);
+            connect(configureNotificationChannel, &QAction::triggered, this, [=]() {
+                slotConfigureNotification(room);
+            });
+            menu.addAction(configureNotificationChannel);
+        }
         menu.addSeparator();
         auto quitChannel = new QAction(QIcon::fromTheme(QStringLiteral("dialog-close")), i18n("Quit Channel"), &menu);
         connect(quitChannel, &QAction::triggered, this, [=]() {
@@ -173,10 +186,19 @@ void ChannelListView::setModel(QAbstractItemModel *model)
     QListView::setModel(model);
 }
 
+void ChannelListView::slotConfigureNotification(Room *room)
+{
+    if (!room) {
+        return;
+    }
+    ConfigureNotificationDialog dlg(mCurrentRocketChatAccount, this);
+    dlg.setRoom(room);
+    dlg.exec();
+}
+
 void ChannelListView::slotMoveToTeam(const QModelIndex &index)
 {
-    auto *rcAccount = Ruqola::self()->rocketChatAccount();
-    QPointer<SearchTeamDialog> dlg = new SearchTeamDialog(rcAccount, this);
+    QPointer<SearchTeamDialog> dlg = new SearchTeamDialog(mCurrentRocketChatAccount, this);
     if (dlg->exec()) {
         const QString teamId = dlg->teamId();
         if (!teamId.isEmpty()) {
@@ -185,7 +207,7 @@ void ChannelListView::slotMoveToTeam(const QModelIndex &index)
             const QString roomId = index.data(RoomModel::RoomId).toString();
             job->setRoomIds({roomId});
 
-            rcAccount->restApi()->initializeRestApiJob(job);
+            mCurrentRocketChatAccount->restApi()->initializeRestApiJob(job);
             // connect(job, &RocketChatRestApi::TeamAddRoomsJob::teamAddRoomsDone, this, &ChannelListView::slotChannelConvertToTeamDone);
             if (!job->start()) {
                 qCWarning(RUQOLAWIDGETS_LOG) << "Impossible to start TeamAddRoomsJob job";
@@ -200,11 +222,10 @@ void ChannelListView::slotMoveToTeam(const QModelIndex &index)
 void ChannelListView::slotConvertToChannel(const QModelIndex &index)
 {
     const QString teamId = index.data(RoomModel::RoomTeamId).toString();
-    auto *rcAccount = Ruqola::self()->rocketChatAccount();
     auto job = new RocketChatRestApi::TeamsListRoomsJob(this);
     job->setTeamId(teamId);
-    rcAccount->restApi()->initializeRestApiJob(job);
-    connect(job, &RocketChatRestApi::TeamsListRoomsJob::teamListRoomsDone, this, [this, teamId, rcAccount, index](const QJsonObject &obj) {
+    mCurrentRocketChatAccount->restApi()->initializeRestApiJob(job);
+    connect(job, &RocketChatRestApi::TeamsListRoomsJob::teamListRoomsDone, this, [this, teamId, index](const QJsonObject &obj) {
         const QVector<TeamRoom> teamRooms = TeamRoom::parseTeamRooms(obj);
         QStringList listRoomIdToDelete;
         if (!teamRooms.isEmpty()) {
@@ -223,7 +244,7 @@ void ChannelListView::slotConvertToChannel(const QModelIndex &index)
         auto job = new RocketChatRestApi::TeamConvertToChannelJob(this);
         job->setTeamId(teamId);
         job->setRoomsToRemove(listRoomIdToDelete);
-        rcAccount->restApi()->initializeRestApiJob(job);
+        mCurrentRocketChatAccount->restApi()->initializeRestApiJob(job);
         connect(job, &RocketChatRestApi::TeamConvertToChannelJob::teamConvertToChannelDone, this, []() {
             // TODO ?
         });
@@ -249,10 +270,9 @@ void ChannelListView::slotConvertToTeam(const QModelIndex &index, Room::RoomType
             qCWarning(RUQOLAWIDGETS_LOG) << "We can't convert Direct to Team. It's a bug";
             break;
         case Room::RoomType::Channel: {
-            auto *rcAccount = Ruqola::self()->rocketChatAccount();
             auto job = new RocketChatRestApi::ChannelsConvertToTeamJob(this);
             job->setChannelId(roomId);
-            rcAccount->restApi()->initializeRestApiJob(job);
+            mCurrentRocketChatAccount->restApi()->initializeRestApiJob(job);
             connect(job, &RocketChatRestApi::ChannelsConvertToTeamJob::channelConvertToTeamDone, this, &ChannelListView::slotChannelConvertToTeamDone);
             if (!job->start()) {
                 qCWarning(RUQOLAWIDGETS_LOG) << "Impossible to start ChannelsConvertToTeamJob job";
@@ -260,10 +280,9 @@ void ChannelListView::slotConvertToTeam(const QModelIndex &index, Room::RoomType
             break;
         }
         case Room::RoomType::Private: {
-            auto *rcAccount = Ruqola::self()->rocketChatAccount();
             auto job = new RocketChatRestApi::GroupsConvertToTeamJob(this);
             job->setRoomId(roomId);
-            rcAccount->restApi()->initializeRestApiJob(job);
+            mCurrentRocketChatAccount->restApi()->initializeRestApiJob(job);
             connect(job, &RocketChatRestApi::GroupsConvertToTeamJob::groupConvertToTeamDone, this, &ChannelListView::slotGroupConvertToTeamDone);
             if (!job->start()) {
                 qCWarning(RUQOLAWIDGETS_LOG) << "Impossible to start ChannelsConvertToTeamJob job";
@@ -290,12 +309,11 @@ void ChannelListView::slotGroupConvertToTeamDone(const QJsonObject &obj)
 
 void ChannelListView::slotMarkAsChannel(const QModelIndex &index, bool markAsRead)
 {
-    auto *rcAccount = Ruqola::self()->rocketChatAccount();
     const QString roomId = index.data(RoomModel::RoomId).toString();
     if (markAsRead) {
-        rcAccount->markRoomAsRead(roomId);
+        mCurrentRocketChatAccount->markRoomAsRead(roomId);
     } else {
-        rcAccount->markRoomAsUnRead(roomId);
+        mCurrentRocketChatAccount->markRoomAsUnRead(roomId);
     }
 }
 
@@ -311,23 +329,20 @@ void ChannelListView::channelSelected(const QModelIndex &index)
 
 void ChannelListView::slotHideChannel(const QModelIndex &index, Room::RoomType roomType)
 {
-    auto *rcAccount = Ruqola::self()->rocketChatAccount();
     const QString roomId = index.data(RoomModel::RoomId).toString();
-    rcAccount->hideRoom(roomId, roomType);
+    mCurrentRocketChatAccount->hideRoom(roomId, roomType);
 }
 
 void ChannelListView::slotLeaveChannel(const QModelIndex &index, Room::RoomType roomType)
 {
-    auto *rcAccount = Ruqola::self()->rocketChatAccount();
     const QString roomId = index.data(RoomModel::RoomId).toString();
-    rcAccount->leaveRoom(roomId, roomType);
+    mCurrentRocketChatAccount->leaveRoom(roomId, roomType);
 }
 
 void ChannelListView::slotChangeFavorite(const QModelIndex &index, bool isFavorite)
 {
-    auto *rcAccount = Ruqola::self()->rocketChatAccount();
     const QString roomId = index.data(RoomModel::RoomId).toString();
-    rcAccount->changeFavorite(roomId, !isFavorite);
+    mCurrentRocketChatAccount->changeFavorite(roomId, !isFavorite);
 }
 
 void ChannelListView::selectChannelRequested(const QString &channelId)
@@ -392,6 +407,7 @@ void ChannelListView::switchToChannel(bool switchToNextUnreadChannel)
     Q_ASSERT(filterModel);
     const int nRooms = filterModel->rowCount();
     if (nRooms == 0) {
+        // FIXME : switch to empty room widget ?
         return;
     }
     int roomIdx = 0;
