@@ -54,6 +54,7 @@ private:
     void slotGroupConvertToTeamDone(const QJsonObject &obj);
     void slotMoveToTeam(const QModelIndex &index);
     void slotConvertToChannel(const QModelIndex &index);
+    void slotConfigureNotification(Room *room);
     Q_REQUIRED_RESULT bool selectChannelByRoomIdOrRoomName(const QString &id, bool roomId);
     void slotRoomRemoved(const QString &roomId);
     void switchToChannel(bool switchToNextUnreadChannel = false);
@@ -61,4 +62,5 @@ private:
     ChannelListDelegate *const mChannelListDelegate;
     RoomListHeadingsProxyModel *const mRoomListHeadingsProxyModel;
     QPointer<RocketChatAccount> mCurrentRocketChatAccount;
+    QMetaObject::Connection mUpdateChannelViewConnect;
 };
