@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,7 +18,7 @@ CreateDirectMessagesWidgetTest::CreateDirectMessagesWidgetTest(QObject *parent)
 
 void CreateDirectMessagesWidgetTest::shouldHaveDefaultValues()
 {
-    CreateDirectMessagesWidget w;
+    CreateDirectMessagesWidget w(nullptr);
 
     auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
