@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,7 +22,7 @@ SearchMessageDialogTest::SearchMessageDialogTest(QObject *parent)
 
 void SearchMessageDialogTest::shouldHaveDefaultValues()
 {
-    SearchMessageDialog w;
+    SearchMessageDialog w(nullptr);
     QVERIFY(!w.windowTitle().isEmpty());
 
     auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
