@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -53,14 +53,14 @@ void ChannelSearchNameLineEdit::slotSearchDone(const QJsonObject &obj)
     Channel c;
     QVector<Channel> channelList;
     const QJsonArray rooms = obj.value(QLatin1String("result")).toArray();
-    const int roomsSize(rooms.size());
+    const auto roomsSize(rooms.size());
     channelList.reserve(roomsSize);
-    for (int i = 0; i < roomsSize; i++) {
+    for (auto i = 0; i < roomsSize; i++) {
         const QJsonObject o = rooms.at(i).toObject();
         Channel channel;
         channel.parseChannel(o, Channel::ChannelType::Room);
         // Verify that it's valid
-        channelList.append(channel);
+        channelList.append(std::move(channel));
     }
     mChannelCompleterModel->insertChannels(channelList);
 }
