@@ -103,7 +103,7 @@ void SearchTreeBaseWidget::finishSearching()
 
 void SearchTreeBaseWidget::resizeColumToContents()
 {
-    for (int i = 0; i < mTreeView->header()->count(); i++) {
+    for (int i = 0, total = mTreeView->header()->count(); i < total; ++i) {
         if (!mModel->excludeResizeToContentColumns().contains(i)) {
             mTreeView->resizeColumnToContents(i);
         }
