@@ -56,6 +56,14 @@ void MyAccountPreferenceConfigureWidgetTest::shouldHaveDefaultValues()
     QCOMPARE(pushNotificationLabel->textFormat(), Qt::PlainText);
     QVERIFY(!pushNotificationLabel->text().isEmpty());
 
+    auto viewModeLabel = w.findChild<QLabel *>(QStringLiteral("viewModeLabel"));
+    QVERIFY(viewModeLabel);
+    QCOMPARE(viewModeLabel->textFormat(), Qt::PlainText);
+    QVERIFY(!viewModeLabel->text().isEmpty());
+
+    auto mViewMode = w.findChild<QComboBox *>(QStringLiteral("mViewMode"));
+    QVERIFY(mViewMode);
+
     auto mUseEmoji = w.findChild<QCheckBox *>(QStringLiteral("mUseEmoji"));
     QVERIFY(mUseEmoji);
     QVERIFY(!mUseEmoji->isChecked()); // False by default as we didn't load values yet
@@ -71,8 +79,8 @@ void MyAccountPreferenceConfigureWidgetTest::shouldHaveDefaultValues()
     QVERIFY(!mHideRoles->isChecked());
     QVERIFY(!mHideRoles->text().isEmpty());
 
-    auto mhideAvatars = w.findChild<QCheckBox *>(QStringLiteral("mhideAvatars"));
-    QVERIFY(mhideAvatars);
-    QVERIFY(!mhideAvatars->isChecked());
-    QVERIFY(!mhideAvatars->text().isEmpty());
+    auto mDisplayAvatars = w.findChild<QCheckBox *>(QStringLiteral("mDisplayAvatars"));
+    QVERIFY(mDisplayAvatars);
+    QVERIFY(!mDisplayAvatars->isChecked());
+    QVERIFY(!mDisplayAvatars->text().isEmpty());
 }
