@@ -29,10 +29,11 @@ private:
     QComboBox *const mDesktopNotification;
     QComboBox *const mEmailNotification;
     QComboBox *const mPushNotification;
+    QComboBox *const mViewMode;
     QCheckBox *const mUseEmoji;
     QCheckBox *const mConvertAsciiEmoji;
     QCheckBox *const mHideRoles;
-    QCheckBox *const mhideAvatars;
+    QCheckBox *const mDisplayAvatars;
     RocketChatAccount *const mRocketChatAccount;
     bool mChanged = false;
 };
