@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -121,13 +121,6 @@ void ChannelActionPopupMenu::createMenu()
         Q_EMIT actionRequested(RoomHeaderWidget::ExportMessages);
     });
 
-    mMenu->addSeparator();
-    mFollowMessage = new QAction(i18n("Follow Message..."), this);
-    mMenu->addAction(mFollowMessage);
-    connect(mFollowMessage, &QAction::triggered, this, [this]() {
-        Q_EMIT actionRequested(RoomHeaderWidget::FollowMessages);
-    });
-
     mMenu->addSeparator();
     mOffTheRecordMessages = new QAction(i18n("OTR"), this);
     mOffTheRecordMessages->setCheckable(true);
@@ -172,10 +165,9 @@ void ChannelActionPopupMenu::slotUpdateMenu()
     mAutoTranslate->setVisible(mCurrentRocketChatAccount->hasAutotranslateSupport());
     mAutoTranslateSeparator->setVisible(mCurrentRocketChatAccount->autoTranslateEnabled());
 
-    bool hasInviteUserSupport = mCurrentRocketChatAccount->hasInviteUserSupport();
     bool hasPermissionInviteUserSupport = mRoom && mRoom->hasPermission(QStringLiteral("create-invite-links"));
-    mInviteUsersGenerateUrl->setVisible(hasInviteUserSupport && hasPermissionInviteUserSupport);
-    mInviteUsersGenerateUrlSeparator->setVisible(hasInviteUserSupport && hasPermissionInviteUserSupport);
+    mInviteUsersGenerateUrl->setVisible(hasPermissionInviteUserSupport);
+    mInviteUsersGenerateUrlSeparator->setVisible(hasPermissionInviteUserSupport);
     mStartVideoChat->setVisible(mCurrentRocketChatAccount->jitsiEnabled());
 
     mAddUserInRoomsSeparator->setVisible(mRoom && mRoom->canBeModify());
@@ -187,9 +179,6 @@ void ChannelActionPopupMenu::slotUpdateMenu()
 
     mExportMessages->setVisible(mCurrentRocketChatAccount->hasPermission(QStringLiteral("mail-messages")));
 
-    // FIXME Disable for the moment
-    mFollowMessage->setVisible(false && mCurrentRocketChatAccount->threadsEnabled());
-
     // FIXME Disable for the moment
     mOffTheRecordMessages->setVisible(false && mCurrentRocketChatAccount->otrEnabled() && mRoom->channelType() == Room::RoomType::Direct);
 
