@@ -5,16 +5,14 @@
 */
 
 #include "messagedelegatehelperbase.h"
-#include "messagedelegateutils.h"
+#include "delegateutils/messagedelegateutils.h"
 #include "rocketchataccount.h"
 #include "ruqola.h"
 #include "ruqolawidgets_selection_debug.h"
 #include "textconverter.h"
 
 #include <QAbstractTextDocumentLayout>
-#include <QClipboard>
 #include <QDrag>
-#include <QGuiApplication>
 #include <QListView>
 #include <QMimeData>
 #include <QPainter>
@@ -24,11 +22,12 @@
 
 MessageDelegateHelperBase::~MessageDelegateHelperBase() = default;
 
-MessageDelegateHelperBase::MessageDelegateHelperBase(QListView *view, TextSelection *textSelection)
+MessageDelegateHelperBase::MessageDelegateHelperBase(RocketChatAccount *account, QListView *view, TextSelectionImpl *textSelectionImpl)
     : mListView(view)
-    , mSelection(textSelection)
+    , mSelectionImpl(textSelectionImpl)
+    , mRocketChatAccount(account)
 {
-    connect(mSelection, &TextSelection::repaintNeeded, this, &MessageDelegateHelperBase::updateView);
+    connect(mSelectionImpl->textSelection(), &TextSelection::repaintNeeded, this, &MessageDelegateHelperBase::updateView);
 }
 
 void MessageDelegateHelperBase::updateView(const QModelIndex &index)
@@ -45,13 +44,13 @@ bool MessageDelegateHelperBase::handleMouseEvent(const MessageAttachment &msgAtt
 {
     switch (mouseEvent->type()) {
     case QEvent::MouseMove: {
-        if (!mMightStartDrag) {
+        if (!mSelectionImpl->mightStartDrag()) {
             if (const auto *doc = documentDescriptionForIndex(msgAttach, attachmentsRect.width() /*, true*/)) { // FIXME ME!
                 const QPoint pos = mouseEvent->pos();
                 const int charPos = charPosition(doc, msgAttach, attachmentsRect, pos, option);
                 if (charPos != -1) {
                     // QWidgetTextControl also has code to support isPreediting()/commitPreedit(), selectBlockOnTripleClick
-                    mSelection->setEnd(index, charPos, msgAttach);
+                    mSelectionImpl->textSelection()->setEnd(index, charPos, msgAttach);
                     return true;
                 }
             }
@@ -60,28 +59,27 @@ bool MessageDelegateHelperBase::handleMouseEvent(const MessageAttachment &msgAtt
     }
     case QEvent::MouseButtonRelease: {
         qCDebug(RUQOLAWIDGETS_SELECTION_LOG) << "released";
-        MessageDelegateUtils::setClipboardSelection(mSelection);
+        MessageDelegateUtils::setClipboardSelection(mSelectionImpl->textSelection());
         // Clicks on links
-        if (!mSelection->hasSelection()) {
+        if (!mSelectionImpl->textSelection()->hasSelection()) {
             if (const auto *doc = documentDescriptionForIndex(msgAttach, attachmentsRect.width() /*, true*/)) { // FIXME
                 const QPoint pos = mouseEvent->pos();
                 const QPoint mouseClickPos = adaptMousePosition(pos, msgAttach, attachmentsRect, option);
                 const QString link = doc->documentLayout()->anchorAt(mouseClickPos);
                 if (!link.isEmpty()) {
-                    auto *rcAccount = Ruqola::self()->rocketChatAccount();
-                    Q_EMIT rcAccount->openLinkRequested(link);
+                    Q_EMIT mRocketChatAccount->openLinkRequested(link);
                     return true;
                 }
             }
-        } else if (mMightStartDrag) {
+        } else if (mSelectionImpl->mightStartDrag()) {
             // clicked into selection, didn't start drag, clear it (like kwrite and QTextEdit)
-            mSelection->clear();
+            mSelectionImpl->textSelection()->clear();
         }
         // don't return true here, we need to send mouse release events to other helpers (ex: click on image)
         break;
     }
     case QEvent::MouseButtonDblClick: {
-        if (!mSelection->hasSelection()) {
+        if (!mSelectionImpl->textSelection()->hasSelection()) {
             if (const auto *doc = documentDescriptionForIndex(msgAttach, attachmentsRect.width() /*, true*/)) { // FIXME ME!
                 const QPoint pos = mouseEvent->pos();
                 const int charPos = charPosition(doc, msgAttach, attachmentsRect, pos, option);
@@ -89,14 +87,14 @@ bool MessageDelegateHelperBase::handleMouseEvent(const MessageAttachment &msgAtt
                 if (charPos == -1) {
                     return false;
                 }
-                mSelection->selectWordUnderCursor(index, msgAttach, charPos, this);
+                mSelectionImpl->textSelection()->selectWordUnderCursor(index, charPos, this, msgAttach);
                 return true;
             }
         }
         break;
     }
     case QEvent::MouseButtonPress: {
-        mMightStartDrag = false;
+        mSelectionImpl->setMightStartDrag(false);
         mCurrentIndex = QModelIndex();
         if (const auto *doc = documentDescriptionForIndex(msgAttach, attachmentsRect.width() /*, true*/)) { // FIXME ME!
             const QPoint pos = mouseEvent->pos();
@@ -105,9 +103,9 @@ bool MessageDelegateHelperBase::handleMouseEvent(const MessageAttachment &msgAtt
             if (charPos == -1) {
                 return false;
             }
-            // TODO fix mSelection->contains with attachment
-            if (mSelection->contains(index, charPos) && doc->documentLayout()->hitTest(pos, Qt::ExactHit) != -1) {
-                mMightStartDrag = true;
+            // TODO fix mSelectionImpl->contains with attachment
+            if (mSelectionImpl->textSelection()->contains(index, charPos) && doc->documentLayout()->hitTest(pos, Qt::ExactHit) != -1) {
+                mSelectionImpl->setMightStartDrag(true);
                 mCurrentIndex = index;
                 return true;
             }
@@ -115,10 +113,10 @@ bool MessageDelegateHelperBase::handleMouseEvent(const MessageAttachment &msgAtt
             // QWidgetTextControl also has code to support selectBlockOnTripleClick, shift to extend selection
             // (look there if you want to add these things)
 
-            mSelection->setStart(index, charPos, msgAttach);
+            mSelectionImpl->textSelection()->setStart(index, charPos, msgAttach);
             return true;
         } else {
-            mSelection->clear();
+            mSelectionImpl->textSelection()->clear();
         }
         break;
     }
@@ -134,12 +132,12 @@ bool MessageDelegateHelperBase::maybeStartDrag(const MessageAttachment &msgAttac
                                                const QStyleOptionViewItem &option,
                                                const QModelIndex &index)
 {
-    if (!mMightStartDrag || index != mCurrentIndex || !attachmentsRect.contains(mouseEvent->pos())) {
+    if (!mSelectionImpl->mightStartDrag() || index != mCurrentIndex || !attachmentsRect.contains(mouseEvent->pos())) {
         return false;
     }
 
     auto mimeData = new QMimeData;
-    mimeData->setUrls({Ruqola::self()->rocketChatAccount()->attachmentUrlFromLocalCache(msgAttach.link())});
+    mimeData->setUrls({mRocketChatAccount->attachmentUrlFromLocalCache(msgAttach.link())});
 
     auto drag = new QDrag(const_cast<QWidget *>(option.widget));
     drag->setMimeData(mimeData);
@@ -176,7 +174,12 @@ void MessageDelegateHelperBase::drawDescription(const MessageAttachment &msgAtta
         return;
     }
 
-    MessageDelegateUtils::drawSelection(doc, descriptionRect, topPos, painter, index, option, mSelection, msgAttach);
+    MessageDelegateUtils::drawSelection(doc, descriptionRect, topPos, painter, index, option, mSelectionImpl->textSelection(), msgAttach);
+}
+
+void MessageDelegateHelperBase::setRocketChatAccount(RocketChatAccount *newRocketChatAccount)
+{
+    mRocketChatAccount = newRocketChatAccount;
 }
 
 QTextDocument *MessageDelegateHelperBase::documentForIndex(const MessageAttachment &msgAttach) const
@@ -216,14 +219,15 @@ QTextDocument *MessageDelegateHelperBase::documentDescriptionForIndex(const Mess
         return nullptr;
     }
     // Use TextConverter in case it starts with a [](URL) reply marker
-    auto *rcAccount = Ruqola::self()->rocketChatAccount();
     QString needUpdateMessageId; // TODO use it ?
+    // Laurent Ruqola::self()->rocketChatAccount() only for test.
+    auto account = mRocketChatAccount ? mRocketChatAccount : Ruqola::self()->rocketChatAccount();
     const QString contextString = TextConverter::convertMessageText(description,
-                                                                    rcAccount->userName(),
+                                                                    account->userName(),
                                                                     {},
-                                                                    rcAccount->highlightWords(),
-                                                                    rcAccount->emojiManager(),
-                                                                    rcAccount->messageCache(),
+                                                                    account->highlightWords(),
+                                                                    account->emojiManager(),
+                                                                    account->messageCache(),
                                                                     needUpdateMessageId,
                                                                     {},
                                                                     {});
