@@ -6,10 +6,11 @@
 
 #pragma once
 
+#include "delegateutils/textselection.h"
+#include "delegateutils/textselectionimpl.h"
 #include "libruqolawidgets_private_export.h"
 #include "lrucache.h"
 #include "messages/messageattachment.h"
-#include "textselection.h"
 
 #include <QPersistentModelIndex>
 #include <QSize>
@@ -26,10 +27,11 @@ class QHelpEvent;
 
 class Message;
 class QListView;
+class RocketChatAccount;
 class LIBRUQOLAWIDGETS_TESTS_EXPORT MessageDelegateHelperBase : public QObject, public DocumentFactoryInterface
 {
 public:
-    explicit MessageDelegateHelperBase(QListView *view, TextSelection *textSelection);
+    explicit MessageDelegateHelperBase(RocketChatAccount *account, QListView *view, TextSelectionImpl *textSelectionImpl);
     virtual ~MessageDelegateHelperBase();
 
     virtual void
@@ -49,6 +51,8 @@ public:
     void clearTextDocumentCache();
     Q_REQUIRED_RESULT QString urlAt(const QStyleOptionViewItem &option, const MessageAttachment &msgAttach, QRect attachmentsRect, QPoint pos);
 
+    void setRocketChatAccount(RocketChatAccount *newRocketChatAccount);
+
 protected:
     Q_REQUIRED_RESULT virtual QPoint
     adaptMousePosition(const QPoint &pos, const MessageAttachment &msgAttach, QRect attachmentsRect, const QStyleOptionViewItem &option) = 0;
@@ -66,9 +70,8 @@ protected:
                          const QStyleOptionViewItem &option) const;
 
     QListView *const mListView;
-    TextSelection *const mSelection;
-    // TODO use unique mMightStartDrag see messageDelegateHelperText
-    bool mMightStartDrag = false;
+    TextSelectionImpl *const mSelectionImpl;
+    RocketChatAccount *mRocketChatAccount = nullptr;
 
     /**
      * Creates (or retrieves from a cache) the QTextDocument for a given @p index.
