@@ -7,6 +7,8 @@
 #include "messagelistdelegate.h"
 #include "colors.h"
 #include "common/delegatepaintutil.h"
+#include "delegateutils/messagedelegateutils.h"
+#include "delegateutils/textselection.h"
 #include "emoticons/emojimanager.h"
 #include "messageattachmentdelegatehelperfile.h"
 #include "messageattachmentdelegatehelperimage.h"
@@ -16,14 +18,16 @@
 #include "messagedelegatehelperbase.h"
 #include "messagedelegatehelperreactions.h"
 #include "messagedelegatehelpertext.h"
-#include "messagedelegateutils.h"
 #include "misc/avatarcachemanager.h"
 #include "misc/emoticonmenuwidget.h"
 #include "model/messagemodel.h"
 #include "rocketchataccount.h"
+#include "room/delegate/messagelistlayout/messagelistcompactlayout.h"
+#include "room/delegate/messagelistlayout/messagelistcozylayout.h"
+#include "room/delegate/messagelistlayout/messagelistnormallayout.h"
 #include "ruqola.h"
+#include "ruqola_thread_message_widgets_debug.h"
 #include "ruqolawidgets_debug.h"
-#include "textselection.h"
 
 #include <QAbstractItemView>
 #include <QApplication>
@@ -41,15 +45,7 @@
 #include <cmath>
 #include <tuple>
 
-static QSizeF dprAwareSize(const QPixmap &pixmap)
-{
-    if (pixmap.isNull()) {
-        return {0, 0}; // prevent division-by-zero
-    }
-    return pixmap.size() / pixmap.devicePixelRatioF();
-}
-
-MessageListDelegate::MessageListDelegate(QListView *view)
+MessageListDelegate::MessageListDelegate(RocketChatAccount *account, QListView *view)
     : QItemDelegate(view)
     , mEditedIcon(QIcon::fromTheme(QStringLiteral("document-edit")))
     , mRolesIcon(QIcon::fromTheme(QStringLiteral("documentinfo")))
@@ -59,51 +55,67 @@ MessageListDelegate::MessageListDelegate(QListView *view)
     , mPinIcon(QIcon::fromTheme(QStringLiteral("pin")))
     , mTranslatedIcon(QIcon::fromTheme(QStringLiteral("languages"))) // TODO use another icon for it. But kde doesn't correct icon perhaps flags ?
     , mListView(view)
-    , mTextSelection(new TextSelection)
-    , mHelperText(new MessageDelegateHelperText(view, mTextSelection))
-    , mHelperAttachmentImage(new MessageAttachmentDelegateHelperImage(view, mTextSelection))
-    , mHelperAttachmentFile(new MessageAttachmentDelegateHelperFile(view, mTextSelection))
-    , mHelperReactions(new MessageDelegateHelperReactions)
-    , mHelperAttachmentVideo(new MessageAttachmentDelegateHelperVideo(view, mTextSelection))
-    , mHelperAttachmentSound(new MessageAttachmentDelegateHelperSound(view, mTextSelection))
-    , mHelperAttachmentText(new MessageAttachmentDelegateHelperText(view, mTextSelection))
+    , mTextSelectionImpl(new TextSelectionImpl)
+    , mHelperText(new MessageDelegateHelperText(account, view, mTextSelectionImpl))
+    , mHelperAttachmentImage(new MessageAttachmentDelegateHelperImage(account, view, mTextSelectionImpl))
+    , mHelperAttachmentFile(new MessageAttachmentDelegateHelperFile(account, view, mTextSelectionImpl))
+    , mHelperReactions(new MessageDelegateHelperReactions(account))
+    , mHelperAttachmentVideo(new MessageAttachmentDelegateHelperVideo(account, view, mTextSelectionImpl))
+    , mHelperAttachmentSound(new MessageAttachmentDelegateHelperSound(account, view, mTextSelectionImpl))
+    , mHelperAttachmentText(new MessageAttachmentDelegateHelperText(account, view, mTextSelectionImpl))
     , mAvatarCacheManager(new AvatarCacheManager(Utils::AvatarType::User, this))
+    , mMessageListLayoutBase(new MessageListCompactLayout(this))
 {
-    mTextSelection->setTextHelperFactory(mHelperText.data());
-    mTextSelection->setAttachmentFactories({mHelperAttachmentImage.data(),
-                                            mHelperAttachmentFile.data(),
-                                            mHelperAttachmentVideo.data(),
-                                            mHelperAttachmentSound.data(),
-                                            mHelperAttachmentText.data()});
-    KColorScheme scheme = Colors::self().schemeView();
+    mTextSelectionImpl->textSelection()->setTextHelperFactory(mHelperText.data());
+    mTextSelectionImpl->textSelection()->setAttachmentFactories({mHelperAttachmentImage.data(),
+                                                                 mHelperAttachmentFile.data(),
+                                                                 mHelperAttachmentVideo.data(),
+                                                                 mHelperAttachmentSound.data(),
+                                                                 mHelperAttachmentText.data()});
     // Hardcode color otherwise in dark mode otherwise scheme.background(KColorScheme::NeutralBackground).color(); is not correct for text color.
     mEditColorMode = QColor(255, 170, 127);
-    mThreadedMessageBackgroundColor = Colors::self().schemeWindow().background(KColorScheme::AlternateBackground).color();
-    mOpenDiscussionColorMode = scheme.foreground(KColorScheme::LinkText).color();
-    mReplyThreadColorMode = scheme.foreground(KColorScheme::NegativeText).color();
+    connect(&Colors::self(), &Colors::needToUpdateColors, this, &MessageListDelegate::slotUpdateColors);
+    slotUpdateColors();
 }
 
 MessageListDelegate::~MessageListDelegate()
 {
-    delete mTextSelection;
+    delete mTextSelectionImpl;
+}
+
+void MessageListDelegate::slotUpdateColors()
+{
+    const KColorScheme scheme = Colors::self().schemeView();
+    mThreadedMessageBackgroundColor = Colors::self().schemeWindow().background(KColorScheme::AlternateBackground).color();
+    mOpenDiscussionColorMode = scheme.foreground(KColorScheme::LinkText).color();
+    mReplyThreadColorMode = scheme.foreground(KColorScheme::NegativeText).color();
+    updateView();
+}
+
+MessageListLayoutBase::Layout MessageListDelegate::doLayout(const QStyleOptionViewItem &option, const QModelIndex &index) const
+{
+    return mMessageListLayoutBase->doLayout(option, index);
 }
 
 void MessageListDelegate::setRocketChatAccount(RocketChatAccount *rcAccount)
 {
-    mAvatarCacheManager->setCurrentRocketChatAccount(rcAccount);
+    if (mRocketChatAccount) {
+        disconnect(mRocketChatAccount, &RocketChatAccount::ownUserPreferencesChanged, this, &MessageListDelegate::switchMessageLayout);
+    }
     mRocketChatAccount = rcAccount;
-}
+    connect(mRocketChatAccount, &RocketChatAccount::ownUserPreferencesChanged, this, &MessageListDelegate::switchMessageLayout);
 
-static qreal basicMargin()
-{
-    return 8;
-}
+    mAvatarCacheManager->setCurrentRocketChatAccount(mRocketChatAccount);
+    // Switch messageLayout after set rocketchatAccount
+    switchMessageLayout();
 
-static QSize timeStampSize(const QString &timeStampText, const QStyleOptionViewItem &option)
-{
-    // This gives incorrect results (too small bounding rect), no idea why!
-    // const QSize timeSize = painter->fontMetrics().boundingRect(timeStampText).size();
-    return {option.fontMetrics.horizontalAdvance(timeStampText), option.fontMetrics.height()};
+    mHelperText->setRocketChatAccount(mRocketChatAccount);
+    mHelperAttachmentImage->setRocketChatAccount(mRocketChatAccount);
+    mHelperAttachmentFile->setRocketChatAccount(mRocketChatAccount);
+    mHelperReactions->setRocketChatAccount(mRocketChatAccount);
+    mHelperAttachmentVideo->setRocketChatAccount(mRocketChatAccount);
+    mHelperAttachmentSound->setRocketChatAccount(mRocketChatAccount);
+    mHelperAttachmentText->setRocketChatAccount(mRocketChatAccount);
 }
 
 QPixmap MessageListDelegate::makeAvatarPixmap(const QWidget *widget, const QModelIndex &index, int maxHeight) const
@@ -124,204 +136,6 @@ QPixmap MessageListDelegate::makeAvatarPixmap(const QWidget *widget, const QMode
     }
 }
 
-bool MessageListDelegate::showIgnoreMessages(const QModelIndex &index) const
-{
-    const bool isIgnoredMessage = index.data(MessageModel::Ignored).toBool();
-    const bool isDirectMessage = index.data(MessageModel::DirectChannels).toBool();
-    return isIgnoredMessage && !isDirectMessage;
-}
-
-// [Optional date header]
-// [margin] <pixmap> [margin] <sender> [margin] <editicon> [margin] <text message> [margin] <add reaction> [margin] <timestamp> [margin/2]
-//                                                                  <attachments>
-//                                                                  <reactions>
-//                                                                  <N replies>
-MessageListDelegate::Layout MessageListDelegate::doLayout(const QStyleOptionViewItem &option, const QModelIndex &index) const
-{
-    const Message *message = index.data(MessageModel::MessagePointer).value<Message *>();
-    Q_ASSERT(message);
-    const int iconSize = option.widget->style()->pixelMetric(QStyle::PM_ButtonIconSize);
-
-    const auto sameSenderAsPreviousMessage = [&] {
-        if (index.row() < 1) {
-            return false;
-        }
-
-        const auto previousIndex = index.siblingAtRow(index.row() - 1);
-        const auto previousMessage = previousIndex.data(MessageModel::MessagePointer).value<Message *>();
-        Q_ASSERT(previousMessage);
-
-        auto toTuple = [](const Message *message) {
-            return std::make_tuple(message->userId(), message->threadMessageId(), QDateTime::fromMSecsSinceEpoch(message->timeStamp()).date());
-        };
-        return toTuple(message) == toTuple(previousMessage);
-    }();
-
-    Layout layout;
-    layout.senderText = QLatin1Char('@') + message->username();
-    layout.senderFont = option.font;
-    layout.senderFont.setBold(true);
-    layout.sameSenderAsPreviousMessage = sameSenderAsPreviousMessage;
-    const QFontMetricsF senderFontMetrics(layout.senderFont);
-    const qreal senderAscent = senderFontMetrics.ascent();
-    const QSizeF senderTextSize = senderFontMetrics.size(Qt::TextSingleLine, layout.senderText);
-
-    if (mRocketChatAccount && !mRocketChatAccount->hideAvatars()) {
-        layout.avatarPixmap = makeAvatarPixmap(option.widget, index, senderTextSize.height());
-    }
-
-    QRect usableRect = option.rect;
-    const bool displayLastSeenMessage = index.data(MessageModel::DisplayLastSeenMessage).toBool();
-    if (index.data(MessageModel::DateDiffersFromPrevious).toBool()) {
-        usableRect.setTop(usableRect.top() + option.fontMetrics.height());
-    } else if (displayLastSeenMessage) {
-        layout.displayLastSeenMessageY = usableRect.top();
-    }
-
-    layout.usableRect = usableRect; // Just for the top, for now. The left will move later on.
-
-    const qreal margin = basicMargin();
-    const int senderX = option.rect.x() + dprAwareSize(layout.avatarPixmap).width() + 2 * margin;
-    int textLeft = senderX + senderTextSize.width() + margin;
-
-    // Roles icon
-    const bool hasRoles = !index.data(MessageModel::Roles).toString().isEmpty() && mRocketChatAccount && !mRocketChatAccount->hideRoles();
-    if (hasRoles) {
-        textLeft += iconSize + margin;
-    }
-
-    // Edit icon
-    const int editIconX = textLeft;
-    if (message->wasEdited()) {
-        textLeft += iconSize + margin;
-    }
-
-    const int favoriteIconX = textLeft;
-    // Favorite icon
-    if (message->isStarred()) {
-        textLeft += iconSize + margin;
-    }
-
-    const int pinIconX = textLeft;
-    // Pin icon
-    if (message->isPinned()) {
-        textLeft += iconSize + margin;
-    }
-
-    const int followingIconX = textLeft;
-    layout.messageIsFollowing = mRocketChatAccount && message->replies().contains(mRocketChatAccount->userId());
-    // Following icon
-    if (layout.messageIsFollowing) {
-        textLeft += iconSize + margin;
-    }
-
-    const int translatedIconX = textLeft;
-    // translated icon
-    if (message->isAutoTranslated()) {
-        textLeft += iconSize + margin;
-    }
-
-    const int showIgnoreMessageIconX = textLeft;
-    // showIgnoreMessage icon
-    const bool ignoreMessage = showIgnoreMessages(index);
-    if (ignoreMessage) {
-        textLeft += iconSize + margin;
-    }
-
-    // Timestamp
-    layout.timeStampText = index.data(MessageModel::Timestamp).toString();
-    const QSize timeSize = timeStampSize(layout.timeStampText, option);
-
-    // Message (using the rest of the available width)
-    const int widthAfterMessage = iconSize + margin + timeSize.width() + margin / 2;
-    const int maxWidth = qMax(30, option.rect.width() - textLeft - widthAfterMessage);
-    layout.baseLine = 0;
-    const QSize textSize = mHelperText->sizeHint(index, maxWidth, option, &layout.baseLine);
-    int attachmentsY;
-    const int textVMargin = 3; // adjust this for "compactness"
-    if (textSize.isValid()) {
-        layout.textRect = QRect(textLeft, usableRect.top() + textVMargin, maxWidth, textSize.height() + textVMargin);
-        attachmentsY = layout.textRect.y() + layout.textRect.height();
-        layout.baseLine += layout.textRect.top(); // make it absolute
-    } else {
-        attachmentsY = usableRect.top() + textVMargin;
-        layout.baseLine = attachmentsY + option.fontMetrics.ascent();
-    }
-    layout.usableRect.setLeft(textLeft);
-
-    // Align top of sender rect so it matches the baseline of the richtext
-    layout.senderRect = QRectF(senderX, layout.baseLine - senderAscent, senderTextSize.width(), senderTextSize.height());
-    // Align top of avatar with top of sender rect
-    layout.avatarPos = QPointF(option.rect.x() + margin, layout.senderRect.y());
-    // Same for the roles and edit icon
-    if (hasRoles) {
-        layout.rolesIconRect = QRect(editIconX - iconSize - margin, layout.senderRect.y(), iconSize, iconSize);
-    }
-    if (message->wasEdited()) {
-        layout.editedIconRect = QRect(editIconX, layout.senderRect.y(), iconSize, iconSize);
-    }
-
-    if (message->isStarred()) {
-        layout.favoriteIconRect = QRect(favoriteIconX, layout.senderRect.y(), iconSize, iconSize);
-    }
-
-    if (message->isPinned()) {
-        layout.pinIconRect = QRect(pinIconX, layout.senderRect.y(), iconSize, iconSize);
-    }
-    if (layout.messageIsFollowing) {
-        layout.followingIconRect = QRect(followingIconX, layout.senderRect.y(), iconSize, iconSize);
-    }
-    if (message->isAutoTranslated()) {
-        layout.translatedIconRect = QRect(translatedIconX, layout.senderRect.y(), iconSize, iconSize);
-    }
-
-    if (ignoreMessage) {
-        layout.showIgnoredMessageIconRect = QRect(showIgnoreMessageIconX, layout.senderRect.y(), iconSize, iconSize);
-        layout.showIgnoreMessage = index.data(MessageModel::ShowIgnoredMessage).toBool();
-    }
-
-    layout.addReactionRect = QRect(textLeft + maxWidth, layout.senderRect.y(), iconSize, iconSize);
-    layout.timeStampPos = QPoint(option.rect.width() - timeSize.width() - margin / 2, layout.baseLine);
-    layout.timeStampRect = QRect(QPoint(layout.timeStampPos.x(), usableRect.top()), timeSize);
-
-    if (message->attachments().isEmpty()) {
-        layout.reactionsY = attachmentsY;
-    } else {
-        const auto attachments = message->attachments();
-        QSize attachmentsSize;
-        int topAttachment = attachmentsY;
-        // TODO add spacing between attachment
-        for (const MessageAttachment &msgAttach : attachments) {
-            const MessageDelegateHelperBase *helper = attachmentsHelper(msgAttach);
-            if (attachmentsSize.isEmpty()) {
-                attachmentsSize = helper ? helper->sizeHint(msgAttach, index, maxWidth, option) : QSize(0, 0);
-                layout.attachmentsRectList.append(QRect(layout.senderRect.x(), topAttachment, attachmentsSize.width(), attachmentsSize.height()));
-                topAttachment += attachmentsSize.height();
-            } else {
-                const QSize attSize = helper ? helper->sizeHint(msgAttach, index, maxWidth, option) : QSize(0, 0);
-                layout.attachmentsRectList.append(QRect(layout.senderRect.x(), topAttachment, attSize.width(), attSize.height()));
-                attachmentsSize = QSize(qMax(attachmentsSize.width(), attSize.width()), attSize.height() + attachmentsSize.height());
-                topAttachment += attSize.height();
-            }
-        }
-        layout.attachmentsRect = QRect(textLeft, attachmentsY, attachmentsSize.width(), attachmentsSize.height());
-        layout.reactionsY = attachmentsY + layout.attachmentsRect.height();
-    }
-    layout.reactionsHeight = mHelperReactions->sizeHint(index, maxWidth, option).height();
-
-    // Replies
-    layout.repliesY = layout.reactionsY + layout.reactionsHeight;
-    if (message->threadCount() > 0) {
-        layout.repliesHeight = option.fontMetrics.height();
-    }
-    // Discussions
-    if (!message->discussionRoomId().isEmpty()) {
-        layout.discussionsHeight = option.fontMetrics.height();
-    }
-
-    return layout;
-}
-
 MessageDelegateHelperBase *MessageListDelegate::attachmentsHelper(const MessageAttachment &msgAttach) const
 {
     switch (msgAttach.attachmentType()) {
@@ -336,11 +150,26 @@ MessageDelegateHelperBase *MessageListDelegate::attachmentsHelper(const MessageA
     case MessageAttachment::NormalText:
         return mHelperAttachmentText.data();
     case MessageAttachment::Unknown:
+        qCWarning(RUQOLAWIDGETS_LOG) << "It's an unknown attachment ! It's a bug for sure";
         break;
     }
     return nullptr;
 }
 
+const QString &MessageListDelegate::searchText() const
+{
+    return mSearchText;
+}
+
+void MessageListDelegate::setSearchText(const QString &newSearchText)
+{
+    if (mSearchText != newSearchText) {
+        mSearchText = newSearchText;
+        mHelperText->setSearchText(mSearchText);
+        clearTextDocumentCache();
+    }
+}
+
 void MessageListDelegate::drawLastSeenLine(QPainter *painter, qint64 displayLastSeenY, const QStyleOptionViewItem &option) const
 {
     const QPen origPen = painter->pen();
@@ -350,10 +179,20 @@ void MessageListDelegate::drawLastSeenLine(QPainter *painter, qint64 displayLast
     painter->setPen(origPen);
 }
 
+MessageDelegateHelperReactions *MessageListDelegate::helperReactions() const
+{
+    return mHelperReactions.data();
+}
+
+MessageDelegateHelperText *MessageListDelegate::helperText() const
+{
+    return mHelperText.data();
+}
+
 void MessageListDelegate::drawDate(QPainter *painter, const QModelIndex &index, const QStyleOptionViewItem &option, bool drawLastSeenLine) const
 {
     const QPen origPen = painter->pen();
-    const qreal margin = basicMargin();
+    const qreal margin = MessageDelegateUtils::basicMargin();
     const QString dateStr = index.data(MessageModel::Date).toString();
     const QSize dateSize = option.fontMetrics.size(Qt::TextSingleLine, dateStr);
     const QRect dateAreaRect(option.rect.x(), option.rect.y(), option.rect.width(), dateSize.height()); // the whole row
@@ -375,9 +214,9 @@ void MessageListDelegate::drawDate(QPainter *painter, const QModelIndex &index,
 void MessageListDelegate::selectAll(const QStyleOptionViewItem &option, const QModelIndex &index)
 {
     Q_UNUSED(option);
-    mTextSelection->selectMessage(index);
+    mTextSelectionImpl->textSelection()->selectMessage(index);
     mListView->update(index);
-    MessageDelegateUtils::setClipboardSelection(mTextSelection);
+    MessageDelegateUtils::setClipboardSelection(mTextSelectionImpl->textSelection());
 }
 
 void MessageListDelegate::clearTextDocumentCache()
@@ -392,12 +231,12 @@ void MessageListDelegate::clearTextDocumentCache()
 
 void MessageListDelegate::clearSelection()
 {
-    mTextSelection->clear();
+    mTextSelectionImpl->textSelection()->clear();
 }
 
 QString MessageListDelegate::urlAt(const QStyleOptionViewItem &option, const QModelIndex &index, QPoint pos) const
 {
-    const Layout layout = doLayout(option, index);
+    const MessageListLayoutBase::Layout layout = doLayout(option, index);
     const auto messageRect = layout.textRect;
     QString url = mHelperText->urlAt(index, pos - messageRect.topLeft());
     if (url.isEmpty()) {
@@ -424,8 +263,8 @@ bool MessageListDelegate::contextMenu(const QStyleOptionViewItem &option, const
         return false;
     }
 
-    const Layout layout = doLayout(option, index);
-    if (layout.senderRect.contains(info.pos)) {
+    const MessageListLayoutBase::Layout layout = doLayout(option, index);
+    if (layout.senderRect.contains(info.pos) && !layout.sameSenderAsPreviousMessage) {
         QMenu menu;
         auto userInfoAction = new QAction(QIcon::fromTheme(QStringLiteral("documentinfo")), i18n("User Info"), &menu);
         connect(userInfoAction, &QAction::triggered, this, [message, this]() {
@@ -455,13 +294,12 @@ bool MessageListDelegate::contextMenu(const QStyleOptionViewItem &option, const
 
 QString MessageListDelegate::selectedText() const
 {
-    const QString str = mTextSelection->selectedText(TextSelection::Format::Text);
-    return str;
+    return mTextSelectionImpl->textSelection()->selectedText(TextSelection::Format::Text);
 }
 
 bool MessageListDelegate::hasSelection() const
 {
-    return mTextSelection->hasSelection();
+    return mTextSelectionImpl->textSelection()->hasSelection();
 }
 
 void MessageListDelegate::setShowThreadContext(bool b)
@@ -483,7 +321,7 @@ void MessageListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
         drawBackground(painter, option, index);
     }
 
-    const Layout layout = doLayout(option, index);
+    const MessageListLayoutBase::Layout layout = doLayout(option, index);
 
     // Draw date if it differs from the previous message
     const bool displayLastSeenMessage = index.data(MessageModel::DisplayLastSeenMessage).toBool();
@@ -503,11 +341,17 @@ void MessageListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
 
     // Message
     if (layout.textRect.isValid()) {
+#if 0
+        painter->save();
+        painter->setPen(QPen(Qt::red));
+        painter->drawRect(layout.textRect);
+        painter->restore();
+#endif
         mHelperText->draw(painter, layout.textRect, index, option);
     }
 
     // Draw the pixmap
-    if (!mRocketChatAccount->hideAvatars() && !layout.sameSenderAsPreviousMessage) {
+    if (mRocketChatAccount->displayAvatars() && !layout.sameSenderAsPreviousMessage) {
         painter->drawPixmap(layout.avatarPos, layout.avatarPixmap);
     }
 
@@ -545,7 +389,7 @@ void MessageListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
         mTranslatedIcon.paint(painter, layout.translatedIconRect);
     }
 
-    if (showIgnoreMessages(index)) {
+    if (MessageDelegateUtils::showIgnoreMessages(index)) {
         const QIcon hideShowIcon = QIcon::fromTheme(layout.showIgnoreMessage ? QStringLiteral("visibility") : QStringLiteral("hint"));
         hideShowIcon.paint(painter, layout.showIgnoredMessageIconRect);
     }
@@ -590,25 +434,7 @@ void MessageListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
 
 QSize MessageListDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    // Note: option.rect in this method is huge (as big as the viewport)
-    const Layout layout = doLayout(option, index);
-
-    int additionalHeight = 0;
-    // A little bit of margin below the very last item, it just looks better
-    if (index.row() == index.model()->rowCount() - 1) {
-        additionalHeight += 4;
-    }
-
-    // contents is date + text + attachments + reactions + replies + discussions (where all of those are optional)
-    const int contentsHeight = layout.repliesY + layout.repliesHeight + layout.discussionsHeight - option.rect.y();
-    const int senderAndAvatarHeight = qMax<int>(layout.senderRect.y() + layout.senderRect.height() - option.rect.y(),
-                                                layout.avatarPos.y() + dprAwareSize(layout.avatarPixmap).height() - option.rect.y());
-
-    // qDebug() << "senderAndAvatarHeight" << senderAndAvatarHeight << "text" << layout.textRect.height()
-    //         << "attachments" << layout.attachmentsRect.height() << "reactions" << layout.reactionsHeight << "total contents" << contentsHeight;
-    // qDebug() << "=> returning" << qMax(senderAndAvatarHeight, contentsHeight) + additionalHeight;
-
-    return {option.rect.width(), qMax(senderAndAvatarHeight, contentsHeight) + additionalHeight};
+    return mMessageListLayoutBase->sizeHint(option, index);
 }
 
 static void positionPopup(QPoint pos, QWidget *parentWindow, QWidget *popup)
@@ -630,7 +456,7 @@ bool MessageListDelegate::mouseEvent(QEvent *event, const QStyleOptionViewItem &
         auto mev = static_cast<QMouseEvent *>(event);
         const Message *message = index.data(MessageModel::MessagePointer).value<Message *>();
 
-        const Layout layout = doLayout(option, index);
+        const MessageListLayoutBase::Layout layout = doLayout(option, index);
 
         const Message::MessageType messageType = message->messageType();
         const bool isSystemMessage = (messageType == Message::System) || (messageType == Message::Information);
@@ -657,9 +483,11 @@ bool MessageListDelegate::mouseEvent(QEvent *event, const QStyleOptionViewItem &
             }
         }
         if (message->threadCount() > 0) {
+            qCDebug(RUQOLA_THREAD_MESSAGE_WIDGETS_LOG) << "Click on thread area";
             const QRect threadRect(layout.usableRect.x(), layout.repliesY, layout.usableRect.width(), layout.repliesHeight);
             if (threadRect.contains(mev->pos())) {
                 const QString threadMessagePreview = index.data(MessageModel::ThreadMessagePreview).toString();
+                qCDebug(RUQOLA_THREAD_MESSAGE_WIDGETS_LOG) << "Click on thread area: " << message->messageId();
                 const bool threadIsFollowing = message->replies().contains(mRocketChatAccount->userId());
                 Q_EMIT mRocketChatAccount->openThreadRequested(message->messageId(),
                                                                threadMessagePreview.isEmpty() ? index.data(MessageModel::MessageConvertedText).toString()
@@ -671,16 +499,15 @@ bool MessageListDelegate::mouseEvent(QEvent *event, const QStyleOptionViewItem &
         if (!message->discussionRoomId().isEmpty()) {
             const QRect discussionRect(layout.usableRect.x(), layout.repliesY + layout.repliesHeight, layout.usableRect.width(), layout.discussionsHeight);
             if (discussionRect.contains(mev->pos())) {
-                qDebug() << " Open discussion" << message->discussionRoomId();
                 // We need to fix rest api first
                 mRocketChatAccount->joinDiscussion(message->discussionRoomId(), QString());
                 return true;
             }
         }
-        if (showIgnoreMessages(index)) {
+        if (MessageDelegateUtils::showIgnoreMessages(index)) {
             if (layout.showIgnoredMessageIconRect.contains(mev->pos())) {
                 mHelperText->removeMessageCache(message->messageId());
-                auto *model = const_cast<QAbstractItemModel *>(index.model());
+                auto model = const_cast<QAbstractItemModel *>(index.model());
                 model->setData(index, !layout.showIgnoreMessage, MessageModel::ShowIgnoredMessage);
                 return true;
             }
@@ -701,7 +528,7 @@ bool MessageListDelegate::mouseEvent(QEvent *event, const QStyleOptionViewItem &
     } else if (eventType == QEvent::MouseButtonPress || eventType == QEvent::MouseMove || eventType == QEvent::MouseButtonDblClick) {
         auto mev = static_cast<QMouseEvent *>(event);
         if (mev->buttons() & Qt::LeftButton) {
-            const Layout layout = doLayout(option, index);
+            const MessageListLayoutBase::Layout layout = doLayout(option, index);
             if (mHelperText->handleMouseEvent(mev, layout.textRect, option, index)) {
                 return true;
             }
@@ -723,7 +550,7 @@ bool MessageListDelegate::mouseEvent(QEvent *event, const QStyleOptionViewItem &
 
 bool MessageListDelegate::maybeStartDrag(QMouseEvent *event, const QStyleOptionViewItem &option, const QModelIndex &index)
 {
-    const Layout layout = doLayout(option, index);
+    const MessageListLayoutBase::Layout layout = doLayout(option, index);
     if (mHelperText->maybeStartDrag(event, layout.textRect, option, index)) {
         return true;
     }
@@ -750,7 +577,7 @@ bool MessageListDelegate::helpEvent(QHelpEvent *helpEvent, QAbstractItemView *vi
             return false;
         }
 
-        const Layout layout = doLayout(option, index);
+        const MessageListLayoutBase::Layout layout = doLayout(option, index);
         if (!message->reactions().isEmpty()) {
             const QRect reactionsRect(layout.senderRect.x(), layout.reactionsY, layout.usableRect.width(), layout.reactionsHeight);
             if (mHelperReactions->handleHelpEvent(helpEvent, view, reactionsRect, option, message)) {
@@ -805,3 +632,35 @@ bool MessageListDelegate::helpEvent(QHelpEvent *helpEvent, QAbstractItemView *vi
     }
     return false;
 }
+
+void MessageListDelegate::switchMessageLayout()
+{
+    // FIXME reactivate it when layout will be implemented correctly
+    // Move this line at end when we reactivate code
+#if 1
+    mMessageListLayoutBase->setRocketChatAccount(mRocketChatAccount);
+    return;
+#else
+    if (mRocketChatAccount) {
+        delete mMessageListLayoutBase;
+        const int i = mRocketChatAccount->ownUserPreferences().messageViewMode();
+        switch (i) {
+        case 0:
+            mMessageListLayoutBase = new MessageListNormalLayout(this);
+            break;
+        case 1:
+            mMessageListLayoutBase = new MessageListCozyLayout(this);
+            break;
+        case 2:
+            mMessageListLayoutBase = new MessageListCompactLayout(this);
+            break;
+        default:
+            qCWarning(RUQOLAWIDGETS_LOG) << "Invalid Message Layout type " << i;
+            mMessageListLayoutBase = new MessageListCompactLayout(this);
+            break;
+        }
+        mMessageListLayoutBase->setRocketChatAccount(mRocketChatAccount);
+        updateView();
+    }
+#endif
+}
