@@ -29,29 +29,24 @@
 #include <QIcon>
 #include <QKeyEvent>
 #include <QMenu>
+#include <QPainter>
 #include <QScrollBar>
-#include <QUrl>
 
 #include <KIO/KUriFilterSearchProviderActions>
 
-MessageListView::MessageListView(Mode mode, QWidget *parent)
-    : QListView(parent)
+MessageListView::MessageListView(RocketChatAccount *account, Mode mode, QWidget *parent)
+    : MessageListViewBase(parent)
     , mMode(mode)
-    , mMessageListDelegate(new MessageListDelegate(this))
+    , mMessageListDelegate(new MessageListDelegate(account, this))
+    , mCurrentRocketChatAccount(account)
 {
     mDebug = !qEnvironmentVariableIsEmpty("RUQOLA_DEBUGGING");
-    mMessageListDelegate->setRocketChatAccount(Ruqola::self()->rocketChatAccount());
+    if (mCurrentRocketChatAccount) {
+        mMessageListDelegate->setRocketChatAccount(mCurrentRocketChatAccount);
+    }
     mMessageListDelegate->setShowThreadContext(mMode != Mode::ThreadEditing);
     setItemDelegate(mMessageListDelegate);
 
-    setSelectionMode(QAbstractItemView::NoSelection);
-    setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    setVerticalScrollMode(QAbstractItemView::ScrollPerPixel); // nicer in case of huge messages
-    setWordWrap(true); // so that the delegate sizeHint is called again when the width changes
-
-    // only the lineedit takes focus
-    setFocusPolicy(Qt::NoFocus);
-
     connect(verticalScrollBar(), &QScrollBar::valueChanged, this, &MessageListView::slotVerticalScrollbarChanged);
 
     // ensure the scrolling behavior isn't jumpy
@@ -68,6 +63,7 @@ MessageListView::MessageListView(Mode mode, QWidget *parent)
     }
     connect(mMessageListDelegate, &MessageListDelegate::showUserInfo, this, &MessageListView::slotShowUserInfo);
     connect(mMessageListDelegate, &MessageListDelegate::startPrivateConversation, this, &MessageListView::slotStartPrivateConversation);
+    connect(mMessageListDelegate, &MessageListDelegate::updateView, this, &MessageListView::slotUpdateView);
 }
 
 MessageListView::~MessageListView()
@@ -75,6 +71,34 @@ MessageListView::~MessageListView()
     qDeleteAll(mPluginTextInterface);
 }
 
+void MessageListView::paintEvent(QPaintEvent *e)
+{
+#if 0
+    if (mRoom) {
+        if (mRoom->roomIsEmpty()) {
+            QPainter p(viewport());
+
+            QFont font = p.font();
+            font.setItalic(true);
+            p.setFont(font);
+
+            p.drawText(QRect(0, 0, width(), height()), Qt::AlignCenter, i18n("Room is Empty."));
+        } else {
+            QListView::paintEvent(e);
+        }
+    } else {
+        QListView::paintEvent(e);
+    }
+#else
+    QListView::paintEvent(e);
+#endif
+}
+
+void MessageListView::slotUpdateView()
+{
+    viewport()->update();
+}
+
 void MessageListView::slotUpdateLastSeen()
 {
     viewport()->update();
@@ -121,8 +145,8 @@ void MessageListView::setChannelSelected(Room *room)
     }
     setRoom(room);
     const QString roomId = room->roomId();
-    Ruqola::self()->rocketChatAccount()->switchingToRoom(roomId);
-    MessageModel *model = Ruqola::self()->rocketChatAccount()->messageModelForRoom(roomId);
+    mCurrentRocketChatAccount->switchingToRoom(roomId);
+    MessageModel *model = mCurrentRocketChatAccount->messageModelForRoom(roomId);
     setModel(model);
     model->activate();
 }
@@ -148,16 +172,6 @@ void MessageListView::setModel(QAbstractItemModel *newModel)
     scrollToBottom();
 }
 
-void MessageListView::resizeEvent(QResizeEvent *ev)
-{
-    QListView::resizeEvent(ev);
-
-    // Fix not being really at bottom when the view gets reduced by the header widget becoming taller
-    checkIfAtBottom();
-    maybeScrollToBottom(); // this forces a layout in QAIV, which then changes the vbar max value
-    updateVerticalPageStep();
-}
-
 void MessageListView::handleKeyPressEvent(QKeyEvent *ev)
 {
     const int key = ev->key();
@@ -176,30 +190,6 @@ void MessageListView::handleKeyPressEvent(QKeyEvent *ev)
     }
 }
 
-void MessageListView::checkIfAtBottom()
-{
-    auto *vbar = verticalScrollBar();
-    mAtBottom = vbar->value() == vbar->maximum();
-}
-
-void MessageListView::maybeScrollToBottom()
-{
-    if (mAtBottom) {
-        scrollToBottom();
-    }
-}
-
-QStyleOptionViewItem MessageListView::listViewOptions() const
-{
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    return QListView::viewOptions();
-#else
-    QStyleOptionViewItem option;
-    initViewItemOption(&option);
-    return option;
-#endif
-}
-
 void MessageListView::contextMenuEvent(QContextMenuEvent *event)
 {
     const QModelIndex index = indexAt(event->pos());
@@ -287,9 +277,12 @@ void MessageListView::contextMenuEvent(QContextMenuEvent *event)
     });
 
     const Message *message = index.data(MessageModel::MessagePointer).value<Message *>();
-    bool messageIsFollowing = mCurrentRocketChatAccount && message->replies().contains(mCurrentRocketChatAccount->userId());
 
-    auto followingToMessageAction =
+    const QString threadMessageId = index.data(MessageModel::ThreadMessageId).toString();
+    const bool messageIsFollowing =
+        threadMessageId.isEmpty() ? message->replies().contains(mCurrentRocketChatAccount->userId()) : index.data(MessageModel::ThreadMessageFollowed).toBool();
+
+    const auto followingToMessageAction =
         new QAction(messageIsFollowing ? QIcon::fromTheme(QStringLiteral("notifications-disabled")) : QIcon::fromTheme(QStringLiteral("notifications")),
                     messageIsFollowing ? i18n("Unfollow Message") : i18n("Follow Message"),
                     &menu);
@@ -469,38 +462,14 @@ void MessageListView::contextMenuEvent(QContextMenuEvent *event)
     }
 }
 
-void MessageListView::mousePressEvent(QMouseEvent *event)
+bool MessageListView::maybeStartDrag(QMouseEvent *event, const QStyleOptionViewItem &option, const QModelIndex &index)
 {
-    mPressedPosition = event->pos();
-    handleMouseEvent(event);
+    return mMessageListDelegate->maybeStartDrag(event, option, index);
 }
 
-void MessageListView::mouseMoveEvent(QMouseEvent *event)
+bool MessageListView::mouseEvent(QMouseEvent *event, const QStyleOptionViewItem &option, const QModelIndex &index)
 {
-    // Drag support
-    const int distance = (event->pos() - mPressedPosition).manhattanLength();
-    if (distance > QApplication::startDragDistance()) {
-        mPressedPosition = {};
-        const QPersistentModelIndex index = indexAt(event->pos());
-        if (index.isValid()) {
-            QStyleOptionViewItem options = listViewOptions();
-            options.rect = visualRect(index);
-            if (mMessageListDelegate->maybeStartDrag(event, options, index)) {
-                return;
-            }
-        }
-    }
-    handleMouseEvent(event);
-}
-
-void MessageListView::mouseReleaseEvent(QMouseEvent *event)
-{
-    handleMouseEvent(event);
-}
-
-void MessageListView::mouseDoubleClickEvent(QMouseEvent *event)
-{
-    handleMouseEvent(event);
+    return mMessageListDelegate->mouseEvent(event, option, index);
 }
 
 void MessageListView::createSeparator(QMenu &menu)
@@ -515,21 +484,9 @@ void MessageListView::slotSelectAll(const QModelIndex &index)
     mMessageListDelegate->selectAll(listViewOptions(), index);
 }
 
-void MessageListView::handleMouseEvent(QMouseEvent *event)
-{
-    const QPersistentModelIndex index = indexAt(event->pos());
-    if (index.isValid()) {
-        QStyleOptionViewItem options = listViewOptions();
-        options.rect = visualRect(index);
-        if (mMessageListDelegate->mouseEvent(event, options, index)) {
-            update(index);
-        }
-    }
-}
-
 void MessageListView::slotTranslateMessage(const QModelIndex &index, bool checked)
 {
-    auto *model = const_cast<QAbstractItemModel *>(index.model());
+    auto model = const_cast<QAbstractItemModel *>(index.model());
     model->setData(index, checked, MessageModel::ShowTranslatedMessage);
 }
 
@@ -609,7 +566,8 @@ void MessageListView::slotShowFullThread(const QModelIndex &index)
     const Message *message = index.data(MessageModel::MessagePointer).value<Message *>();
     const QString threadMessageId = message->threadMessageId();
     QString threadMessagePreview = index.data(MessageModel::ThreadMessagePreview).toString();
-    const bool threadIsFollowing = message->replies().contains(mCurrentRocketChatAccount->userId());
+    const bool threadIsFollowing =
+        threadMessageId.isEmpty() ? message->replies().contains(mCurrentRocketChatAccount->userId()) : index.data(MessageModel::ThreadMessageFollowed).toBool();
     QString messageId = threadMessageId;
     if (threadMessageId.isEmpty()) {
         messageId = message->messageId();
@@ -709,6 +667,11 @@ void MessageListView::scrollTo(const QModelIndex &index, QAbstractItemView::Scro
     connect(verticalScrollBar(), &QScrollBar::valueChanged, this, &MessageListView::slotVerticalScrollbarChanged);
 }
 
+void MessageListView::setSearchText(const QString &str)
+{
+    mMessageListDelegate->setSearchText(str);
+}
+
 MessageListView::Mode MessageListView::mode() const
 {
     return mMode;
@@ -721,11 +684,6 @@ void MessageListView::slotReplyInThread(const QModelIndex &index)
     Q_EMIT replyInThreadRequested(messageId, threadPreview);
 }
 
-void MessageListView::updateVerticalPageStep()
-{
-    verticalScrollBar()->setPageStep(viewport()->height() * 3 / 4);
-}
-
 void MessageListView::slotShowUserInfo(const QString &userName)
 {
     DirectChannelInfoDialog dlg(mCurrentRocketChatAccount, this);
