@@ -7,14 +7,14 @@
 #pragma once
 
 #include "libruqolawidgets_private_export.h"
-#include <QListView>
+#include "misc/messagelistviewbase.h"
 #include <QPointer>
 #include <QVector>
 class MessageListDelegate;
 class RocketChatAccount;
 class Room;
 class PluginTextInterface;
-class LIBRUQOLAWIDGETS_TESTS_EXPORT MessageListView : public QListView
+class LIBRUQOLAWIDGETS_TESTS_EXPORT MessageListView : public MessageListViewBase
 {
     Q_OBJECT
 public:
@@ -24,7 +24,7 @@ public:
         Viewing, /*when we show list of message as mentions, search etc.*/
     };
 
-    explicit MessageListView(MessageListView::Mode mode, QWidget *parent = nullptr);
+    explicit MessageListView(RocketChatAccount *account, MessageListView::Mode mode, QWidget *parent = nullptr);
     ~MessageListView() override;
 
     void setRoom(Room *room);
@@ -48,14 +48,14 @@ public:
 
     void scrollTo(const QModelIndex &index, ScrollHint hint = EnsureVisible) override;
 
-protected:
-    void resizeEvent(QResizeEvent *ev) override;
-    void contextMenuEvent(QContextMenuEvent *event) override;
-    void mousePressEvent(QMouseEvent *event) override;
-    void mouseMoveEvent(QMouseEvent *event) override;
-    void mouseReleaseEvent(QMouseEvent *event) override;
-    void mouseDoubleClickEvent(QMouseEvent *event) override;
+    void setSearchText(const QString &str);
 
+protected:
+    void paintEvent(QPaintEvent *e) override;
+    void contextMenuEvent(QContextMenuEvent *event) override;
+
+    bool mouseEvent(QMouseEvent *event, const QStyleOptionViewItem &option, const QModelIndex &index) override;
+    bool maybeStartDrag(QMouseEvent *event, const QStyleOptionViewItem &option, const QModelIndex &index) override;
 Q_SIGNALS:
     void modelChanged();
     void editMessageRequested(const QString &messageId, const QString &text);
@@ -67,8 +67,6 @@ Q_SIGNALS:
     void replyInThreadRequested(const QString &messageId, const QString &text);
 
 private:
-    void checkIfAtBottom();
-    void maybeScrollToBottom();
     void slotEditMessage(const QModelIndex &index);
     void slotDeleteMessage(const QModelIndex &index);
     void slotReportMessage(const QModelIndex &index);
@@ -80,19 +78,17 @@ private:
     void createSeparator(QMenu &menu);
     void slotVerticalScrollbarChanged(int value);
     void slotReplyInThread(const QModelIndex &index);
-    void updateVerticalPageStep();
     void slotDebugMessage(const QModelIndex &index);
     void slotUpdateLastSeen();
     void slotMarkMessageAsUnread(const QModelIndex &index);
     void slotSelectAll(const QModelIndex &index);
-    void handleMouseEvent(QMouseEvent *event);
     void slotShowFullThread(const QModelIndex &index);
     void slotQuoteMessage(const QModelIndex &index);
     void slotCopyLinkToMessage(const QModelIndex &index);
     void slotFollowMessage(const QModelIndex &index, bool messageIsFollowing);
     Q_REQUIRED_RESULT QString generatePermalink(const QString &messageId) const;
     void slotShowUserInfo(const QString &userName);
-    Q_REQUIRED_RESULT QStyleOptionViewItem listViewOptions() const;
+    void slotUpdateView();
 
 private:
     QPointer<Room> mRoom;
@@ -100,7 +96,5 @@ private:
     MessageListDelegate *const mMessageListDelegate;
     QPointer<RocketChatAccount> mCurrentRocketChatAccount;
     QVector<PluginTextInterface *> mPluginTextInterface;
-    QPoint mPressedPosition;
-    bool mAtBottom = true;
     bool mDebug = false;
 };
