@@ -11,6 +11,6 @@
 #include <QString>
 namespace RoomUtil
 {
-LIBRUQOLAWIDGETS_TESTS_EXPORT Q_REQUIRED_RESULT QString generateUserLink(const QString &userName);
-LIBRUQOLAWIDGETS_TESTS_EXPORT Q_REQUIRED_RESULT QString generatePermalink(const QString &messageId, const QString &roomId, Room::RoomType channelType);
+Q_REQUIRED_RESULT LIBRUQOLAWIDGETS_TESTS_EXPORT QString generateUserLink(const QString &userName);
+Q_REQUIRED_RESULT LIBRUQOLAWIDGETS_TESTS_EXPORT QString generatePermalink(const QString &messageId, const QString &roomId, Room::RoomType channelType);
 }
