@@ -15,12 +15,12 @@
 #include "dialogs/inviteusersdialog.h"
 #include "dialogs/searchmessagedialog.h"
 #include "dialogs/showattachmentdialog.h"
-#include "dialogs/showdiscussionsdialog.h"
 #include "dialogs/showmentionsmessagesdialog.h"
 #include "dialogs/showpinnedmessagesdialog.h"
 #include "dialogs/showsnipperedmessagesdialog.h"
 #include "dialogs/showstarredmessagesdialog.h"
 #include "dialogs/showthreadsdialog.h"
+#include "discussions/showdiscussionsdialog.h"
 #include "exportmessages/exportmessagesdialog.h"
 #include "messagelinewidget.h"
 #include "messagelistview.h"
@@ -40,6 +40,7 @@
 #include "roomquotemessagewidget.h"
 #include "roomreplythreadwidget.h"
 #include "roomwidgetbase.h"
+#include "ruqola_thread_message_widgets_debug.h"
 #include "teams/teamchannelsdialog.h"
 #include "teams/teaminfo.h"
 #include "threadwidget/threadmessagedialog.h"
@@ -290,7 +291,6 @@ void RoomWidget::slotStarredMessages()
     QPointer<ShowStarredMessagesDialog> dlg = new ShowStarredMessagesDialog(mCurrentRocketChatAccount, this);
     dlg->setRoomId(mRoomWidgetBase->roomId());
     dlg->setModel(mCurrentRocketChatAccount->listMessagesFilterProxyModel());
-    dlg->setCurrentRocketChatAccount(mCurrentRocketChatAccount);
     dlg->setRoom(mRoom);
     mCurrentRocketChatAccount->getListMessages(mRoomWidgetBase->roomId(), ListMessagesModel::StarredMessages);
     connect(dlg, &ShowListMessageBaseDialog::goToMessageRequested, this, &RoomWidget::slotGotoMessage);
@@ -305,7 +305,6 @@ void RoomWidget::slotPinnedMessages()
     }
     QPointer<ShowPinnedMessagesDialog> dlg = new ShowPinnedMessagesDialog(mCurrentRocketChatAccount, this);
     dlg->setRoomId(mRoomWidgetBase->roomId());
-    dlg->setCurrentRocketChatAccount(mCurrentRocketChatAccount);
     dlg->setRoom(mRoom);
     dlg->setModel(mCurrentRocketChatAccount->listMessagesFilterProxyModel());
     mCurrentRocketChatAccount->getListMessages(mRoomWidgetBase->roomId(), ListMessagesModel::PinnedMessages);
@@ -322,7 +321,6 @@ void RoomWidget::slotShowMentions()
     QPointer<ShowMentionsMessagesDialog> dlg = new ShowMentionsMessagesDialog(mCurrentRocketChatAccount, this);
     dlg->setRoomId(mRoomWidgetBase->roomId());
     dlg->setModel(mCurrentRocketChatAccount->listMessagesFilterProxyModel());
-    dlg->setCurrentRocketChatAccount(mCurrentRocketChatAccount);
     dlg->setRoom(mRoom);
     mCurrentRocketChatAccount->getListMessages(mRoomWidgetBase->roomId(), ListMessagesModel::MentionsMessages);
     connect(dlg, &ShowListMessageBaseDialog::goToMessageRequested, this, &RoomWidget::slotGotoMessage);
@@ -338,7 +336,6 @@ void RoomWidget::slotSnipperedMessages()
     QPointer<ShowSnipperedMessagesDialog> dlg = new ShowSnipperedMessagesDialog(mCurrentRocketChatAccount, this);
     dlg->setRoomId(mRoomWidgetBase->roomId());
     dlg->setModel(mCurrentRocketChatAccount->listMessagesFilterProxyModel());
-    dlg->setCurrentRocketChatAccount(mCurrentRocketChatAccount);
     dlg->setRoom(mRoom);
     mCurrentRocketChatAccount->getListMessages(mRoomWidgetBase->roomId(), ListMessagesModel::SnipperedMessages);
     connect(dlg, &ShowListMessageBaseDialog::goToMessageRequested, this, &RoomWidget::slotGotoMessage);
@@ -352,7 +349,6 @@ void RoomWidget::slotShowThreads()
         return;
     }
     QPointer<ShowThreadsDialog> dlg = new ShowThreadsDialog(mCurrentRocketChatAccount, this);
-    dlg->setCurrentRocketChatAccount(mCurrentRocketChatAccount);
     dlg->setModel(mCurrentRocketChatAccount->listMessagesFilterProxyModel());
     dlg->setRoomId(mRoomWidgetBase->roomId());
     dlg->setRoom(mRoom);
@@ -373,12 +369,12 @@ void RoomWidget::slotShowDiscussions()
 
 void RoomWidget::slotShowFileAttachments()
 {
-    ShowAttachmentDialog dlg(mCurrentRocketChatAccount, this);
+    auto dlg = new ShowAttachmentDialog(mCurrentRocketChatAccount, this);
     mCurrentRocketChatAccount->roomFiles(mRoomWidgetBase->roomId(), mRoomType);
-    dlg.setModel(mCurrentRocketChatAccount->filesForRoomFilterProxyModel());
-    dlg.setRoomId(mRoomWidgetBase->roomId());
-    dlg.setRoomType(mRoomType);
-    dlg.exec();
+    dlg->setModel(mCurrentRocketChatAccount->filesForRoomFilterProxyModel());
+    dlg->setRoomId(mRoomWidgetBase->roomId());
+    dlg->setRoomType(mRoomType);
+    dlg->show();
 }
 
 void RoomWidget::slotSearchMessages()
@@ -598,7 +594,6 @@ void RoomWidget::slotJumpToUnreadMessage(qint64 numberOfMessage)
         const QString messageId = roomMessageModel->messageIdFromIndex(roomMessageModel->rowCount() - numberOfMessage);
         mRoomWidgetBase->messageListView()->goToMessage(messageId);
     } else {
-        auto job = new RocketChatRestApi::ChannelHistoryJob(this);
         RocketChatRestApi::ChannelHistoryJob::ChannelHistoryInfo info;
         switch (mRoomType) {
         case Room::RoomType::Channel:
@@ -614,6 +609,10 @@ void RoomWidget::slotJumpToUnreadMessage(qint64 numberOfMessage)
             qCWarning(RUQOLAWIDGETS_LOG) << " Problem with room type ";
             break;
         }
+        if (mRoomType == Room::RoomType::Unknown) {
+            return;
+        }
+        auto job = new RocketChatRestApi::ChannelHistoryJob(this);
         info.count = numberOfMessage - roomMessageModel->rowCount() + 1;
         info.roomId = mRoomWidgetBase->roomId();
         const qint64 endDateTime = roomMessageModel->lastTimestamp();
@@ -651,7 +650,6 @@ void RoomWidget::slotGotoMessage(const QString &messageId, const QString &messag
     if (index.isValid()) {
         messageListView->scrollTo(index);
     } else if (!messageDateTimeUtc.isEmpty()) {
-        auto job = new RocketChatRestApi::ChannelHistoryJob(this);
         RocketChatRestApi::ChannelHistoryJob::ChannelHistoryInfo info;
         switch (mRoomType) {
         case Room::RoomType::Channel:
@@ -667,6 +665,10 @@ void RoomWidget::slotGotoMessage(const QString &messageId, const QString &messag
             qCWarning(RUQOLAWIDGETS_LOG) << " Problem with room type ";
             break;
         }
+        if (mRoomType == Room::RoomType::Unknown) {
+            return;
+        }
+        auto job = new RocketChatRestApi::ChannelHistoryJob(this);
         info.roomId = mRoomWidgetBase->roomId();
         const qint64 endDateTime = messageModel->lastTimestamp();
         info.latestMessage = QDateTime::fromMSecsSinceEpoch(endDateTime).toUTC().toString(Qt::ISODateWithMs);
@@ -726,7 +728,7 @@ void RoomWidget::setCurrentRocketChatAccount(RocketChatAccount *account)
         disconnect(mCurrentRocketChatAccount, &RocketChatAccount::openThreadRequested, this, &RoomWidget::slotOpenThreadRequested);
         disconnect(mCurrentRocketChatAccount, &RocketChatAccount::displayReconnectWidget, this, &RoomWidget::slotDisplayReconnectWidget);
         disconnect(mCurrentRocketChatAccount, &RocketChatAccount::loginStatusChanged, this, &RoomWidget::slotLoginStatusChanged);
-        disconnect(mCurrentRocketChatAccount, &RocketChatAccount::needUpdateView, this, &RoomWidget::updateListView);
+        disconnect(mCurrentRocketChatAccount, &RocketChatAccount::needUpdateMessageView, this, &RoomWidget::updateListView);
     }
 
     mCurrentRocketChatAccount = account;
@@ -734,9 +736,10 @@ void RoomWidget::setCurrentRocketChatAccount(RocketChatAccount *account)
     connect(mCurrentRocketChatAccount, &RocketChatAccount::openThreadRequested, this, &RoomWidget::slotOpenThreadRequested);
     connect(mCurrentRocketChatAccount, &RocketChatAccount::displayReconnectWidget, this, &RoomWidget::slotDisplayReconnectWidget);
     connect(mCurrentRocketChatAccount, &RocketChatAccount::loginStatusChanged, this, &RoomWidget::slotLoginStatusChanged);
-    connect(mCurrentRocketChatAccount, &RocketChatAccount::needUpdateView, this, &RoomWidget::updateListView);
+    connect(mCurrentRocketChatAccount, &RocketChatAccount::needUpdateMessageView, this, &RoomWidget::updateListView);
     // TODO verify if we need to show or not reconnect widget
     mRoomHeaderWidget->setCurrentRocketChatAccount(account);
+    mUsersInRoomFlowWidget->setCurrentRocketChatAccount(account);
 }
 
 void RoomWidget::slotLoginStatusChanged()
@@ -756,6 +759,7 @@ void RoomWidget::slotGoBackToRoom()
 
 void RoomWidget::slotOpenThreadRequested(const QString &threadMessageId, const QString &threadMessagePreview, bool threadIsFollowing)
 {
+    qCDebug(RUQOLA_THREAD_MESSAGE_WIDGETS_LOG) << "threadMessageId: " << threadMessageId;
     auto dlg = new ThreadMessageDialog(mCurrentRocketChatAccount, this);
     dlg->setThreadMessageId(threadMessageId);
     dlg->setFollowingThread(threadIsFollowing);
