@@ -5,11 +5,15 @@
 */
 
 #include "ruqolamainwindow.h"
+#include "notificationhistorymanager.h"
 #include "ruqolaglobalconfig.h"
 #include "ruqolawidgets_debug.h"
 
 #include "accountmanager.h"
 #include "administratordialog/administratordialog.h"
+#include "administratorsettingsdialog/administratorsettingsdialog.h"
+
+#include "bannerinfodialog/bannerinfodialog.h"
 #include "config-ruqola.h"
 #include "configuredialog/configuresettingsdialog.h"
 #include "connection.h"
@@ -28,6 +32,7 @@
 #include "model/statusmodel.h"
 #include "model/statusmodelfilterproxymodel.h"
 #include "myaccount/myaccountconfiguredialog.h"
+#include "notificationhistory/notificationhistorydialog.h"
 #include "notifications/notification.h"
 #include "receivetypingnotificationmanager.h"
 #include "registeruser/registeruserdialog.h"
@@ -42,13 +47,19 @@
 #include <KActionCollection>
 #include <KColorSchemeManager>
 #include <KConfigGroup>
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
+#endif
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KNotifyConfigWidget>
 #include <KSharedConfig>
 #include <KStandardAction>
+#include <KToggleFullScreenAction>
 #include <KToolBar>
 #include <QApplication>
 #include <QCommandLineParser>
@@ -61,8 +72,13 @@
 #include <QMenuBar>
 #include <QStatusBar>
 #include <QTemporaryFile>
+#include <QToolButton>
 #include <QWidgetAction>
 
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+#include <KWindowSystem>
+#endif
+
 #if HAVE_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 #include <KUserFeedback/NotificationPopup>
@@ -90,11 +106,12 @@ RuqolaMainWindow::RuqolaMainWindow(QWidget *parent)
     createSystemTray();
     mSwitchChannelTreeManager->setParentWidget(mMainWidget);
     connect(mSwitchChannelTreeManager, &SwitchChannelTreeViewManager::switchToChannel, this, &RuqolaMainWindow::slotHistorySwitchChannel);
-    connect(Ruqola::self()->accountManager(), &AccountManager::currentAccountChanged, this, &RuqolaMainWindow::slotAccountChanged);
-    connect(Ruqola::self()->accountManager(), &AccountManager::updateNotification, this, &RuqolaMainWindow::updateNotification);
-    connect(Ruqola::self()->accountManager(), &AccountManager::roomNeedAttention, this, &RuqolaMainWindow::slotRoomNeedAttention);
-    connect(Ruqola::self()->accountManager(), &AccountManager::messageUrlNotFound, this, &RuqolaMainWindow::slotMessageUrlNotFound);
-    connect(Ruqola::self()->accountManager(), &AccountManager::logoutAccountDone, this, &RuqolaMainWindow::logout);
+    mAccountManager = Ruqola::self()->accountManager();
+    connect(mAccountManager, &AccountManager::currentAccountChanged, this, &RuqolaMainWindow::slotAccountChanged);
+    connect(mAccountManager, &AccountManager::updateNotification, this, &RuqolaMainWindow::updateNotification);
+    connect(mAccountManager, &AccountManager::roomNeedAttention, this, &RuqolaMainWindow::slotRoomNeedAttention);
+    connect(mAccountManager, &AccountManager::messageUrlNotFound, this, &RuqolaMainWindow::slotMessageUrlNotFound);
+    connect(mAccountManager, &AccountManager::logoutAccountDone, this, &RuqolaMainWindow::logout);
 
     slotAccountChanged();
 #if HAVE_KUSERFEEDBACK
@@ -132,6 +149,7 @@ void RuqolaMainWindow::parseCommandLine(QCommandLineParser *parser)
     }
 }
 
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
 void RuqolaMainWindow::slotActivateRequested(const QStringList &arguments, const QString &workingDirectory)
 {
     Q_UNUSED(workingDirectory)
@@ -141,7 +159,11 @@ void RuqolaMainWindow::slotActivateRequested(const QStringList &arguments, const
         parser.parse(arguments);
         parseCommandLine(&parser);
     }
+
+    KWindowSystem::updateStartupId(windowHandle());
+    KWindowSystem::activateWindow(windowHandle());
 }
+#endif
 
 void RuqolaMainWindow::slotRoomNeedAttention()
 {
@@ -171,7 +193,22 @@ void RuqolaMainWindow::setupStatusBar()
     mStatusBarTypingMessage->setObjectName(QStringLiteral("mStatusBarTypingMessage"));
     statusBar()->addPermanentWidget(mStatusBarTypingMessage);
     mAccountOverviewWidget = new AccountsOverviewWidget(this);
+    mAccountOverviewWidget->setObjectName(QStringLiteral("mAccountOverviewWidget"));
     statusBar()->addPermanentWidget(mAccountOverviewWidget);
+    mNotificationToolButton = new QToolButton(this);
+    mNotificationToolButton->setIcon(QIcon::fromTheme(QStringLiteral("notifications")));
+    mNotificationToolButton->setObjectName(QStringLiteral("mNotificationToolButton"));
+    mNotificationToolButton->setToolTip(i18n("Show New Notifications"));
+    mNotificationToolButton->hide(); // Hide at start
+    mNotificationToolButton->setAutoRaise(true);
+    connect(mNotificationToolButton, &QToolButton::clicked, this, &RuqolaMainWindow::slotOpenNotificationHistory);
+    statusBar()->addPermanentWidget(mNotificationToolButton);
+    connect(NotificationHistoryManager::self(), &NotificationHistoryManager::newNotification, this, &RuqolaMainWindow::slotNewNotification);
+}
+
+void RuqolaMainWindow::slotNewNotification()
+{
+    mNotificationToolButton->show();
 }
 
 void RuqolaMainWindow::slotAccountChanged()
@@ -199,6 +236,9 @@ void RuqolaMainWindow::slotAccountChanged()
         updateActions();
         slotPermissionChanged();
     });
+    connect(mCurrentRocketChatAccount, &RocketChatAccount::needUpdateChannelView, this, [this]() {
+        updateActions();
+    });
     connect(mCurrentRocketChatAccount, &RocketChatAccount::raiseWindow, this, &RuqolaMainWindow::slotRaiseWindow);
     connect(mCurrentRocketChatAccount, &RocketChatAccount::permissionChanged, this, &RuqolaMainWindow::slotPermissionChanged);
     connect(mCurrentRocketChatAccount, &RocketChatAccount::registerUserSuccess, this, &RuqolaMainWindow::slotRegisterUserSuccessed);
@@ -242,10 +282,20 @@ void RuqolaMainWindow::slotPermissionChanged()
 
 void RuqolaMainWindow::updateActions()
 {
-    mUnreadOnTop->setChecked(mCurrentRocketChatAccount->sortUnreadOnTop());
-    mRegisterNewUser->setEnabled(mCurrentRocketChatAccount->registrationFromEnabled());
-    mAdministrator->setEnabled(mCurrentRocketChatAccount->isAdministrator());
+    mUnreadOnTop->setChecked(mCurrentRocketChatAccount->ownUserPreferences().showUnread());
+    mRegisterNewUser->setVisible(mCurrentRocketChatAccount->registrationFromEnabled());
     mCreateDiscussion->setEnabled(mCurrentRocketChatAccount->discussionEnabled());
+    const bool isAdministrator{mCurrentRocketChatAccount->isAdministrator()};
+    mAdministrator->setEnabled(isAdministrator);
+    mAdministratorServerSettings->setEnabled(isAdministrator);
+    mAdministratorMenu->setVisible(isAdministrator);
+    mShowRocketChatServerInfo->setVisible(hasBannerInfo());
+    mRoomAvatar->setChecked(mCurrentRocketChatAccount->ownUserPreferences().showRoomAvatar());
+}
+
+bool RuqolaMainWindow::hasBannerInfo() const
+{
+    return mCurrentRocketChatAccount && !mCurrentRocketChatAccount->bannerInfos().isEmpty();
 }
 
 void RuqolaMainWindow::readConfig()
@@ -340,9 +390,17 @@ void RuqolaMainWindow::setupActions()
     connect(mMyAccount, &QAction::triggered, this, &RuqolaMainWindow::slotConfigureMyAccount);
     ac->addAction(QStringLiteral("configure_my_account"), mMyAccount);
 
+    mAdministratorMenu = new KActionMenu(i18n("Administrator"), this);
     mAdministrator = new QAction(i18n("Administrator..."), this);
+    ac->addAction(QStringLiteral("administrator_account_settings"), mAdministrator);
     connect(mAdministrator, &QAction::triggered, this, &RuqolaMainWindow::slotAdministrator);
-    ac->addAction(QStringLiteral("administrator"), mAdministrator);
+    mAdministratorMenu->addAction(mAdministrator);
+    ac->addAction(QStringLiteral("administrator"), mAdministratorMenu);
+
+    mAdministratorServerSettings = new QAction(i18n("Server Settings..."), this);
+    connect(mAdministratorServerSettings, &QAction::triggered, this, &RuqolaMainWindow::slotAdministratorServerSettings);
+    ac->addAction(QStringLiteral("administrator_server_settings"), mAdministratorServerSettings);
+    mAdministratorMenu->addAction(mAdministratorServerSettings);
 
     mDirectory = new QAction(i18n("Directory..."), this);
     connect(mDirectory, &QAction::triggered, this, &RuqolaMainWindow::slotDirectory);
@@ -431,6 +489,23 @@ void RuqolaMainWindow::setupActions()
 
     auto manager = new KColorSchemeManager(this);
     ac->addAction(QStringLiteral("colorscheme_menu"), manager->createSchemeSelectionMenu(this));
+
+    mShowFullScreenAction = KStandardAction::fullScreen(nullptr, nullptr, this, ac);
+    ac->setDefaultShortcut(mShowFullScreenAction, Qt::Key_F11);
+    connect(mShowFullScreenAction, &QAction::toggled, this, &RuqolaMainWindow::slotFullScreen);
+
+    mShowNotifyHistory = new QAction(QIcon::fromTheme(QStringLiteral("notifications")), i18n("Show Notify History"), this);
+    connect(mShowNotifyHistory, &QAction::triggered, this, &RuqolaMainWindow::slotOpenNotificationHistory);
+    ac->addAction(QStringLiteral("show_notify_history"), mShowNotifyHistory);
+
+    mShowRocketChatServerInfo = new QAction(i18n("Show RocketChat Information"), this);
+    connect(mShowRocketChatServerInfo, &QAction::triggered, this, &RuqolaMainWindow::slotRocketChatInformation);
+    ac->addAction(QStringLiteral("show_rocketchat_information"), mShowRocketChatServerInfo);
+
+    mRoomAvatar = new QAction(i18n("Room Avatar"), this);
+    mRoomAvatar->setCheckable(true);
+    connect(mRoomAvatar, &QAction::triggered, this, &RuqolaMainWindow::slotShowRoomAvatar);
+    ac->addAction(QStringLiteral("room_avatar"), mRoomAvatar);
 }
 
 void RuqolaMainWindow::showNextView()
@@ -445,7 +520,7 @@ void RuqolaMainWindow::showPreviousView()
 
 void RuqolaMainWindow::slotClearAccountAlerts()
 {
-    if (auto acct = Ruqola::self()->accountManager()->account()) {
+    if (auto acct = mAccountManager->account()) {
         acct->clearAllUnreadMessages();
     }
 }
@@ -529,19 +604,18 @@ void RuqolaMainWindow::slotConfigure()
 void RuqolaMainWindow::slotAddServer()
 {
     QPointer<CreateNewServerDialog> dlg = new CreateNewServerDialog(this);
-    const QStringList lst = Ruqola::self()->accountManager()->accountsName();
+    const QStringList lst = mAccountManager->accountsName();
     dlg->setExistingAccountName(lst);
     if (dlg->exec()) {
         const AccountManager::AccountManagerInfo info = dlg->accountInfo();
-        Ruqola::self()->accountManager()->addAccount(info);
+        mAccountManager->addAccount(info);
     }
     delete dlg;
 }
 
 void RuqolaMainWindow::slotServerInfo()
 {
-    ServerInfoDialog dlg(this);
-    dlg.setServerConfigInfo(mCurrentRocketChatAccount->serverConfigInfo());
+    ServerInfoDialog dlg(mCurrentRocketChatAccount, this);
     dlg.exec();
 }
 
@@ -572,7 +646,11 @@ void RuqolaMainWindow::slotShowLog()
                 const QString fileName = tempFile.fileName();
                 tempFile.close();
                 auto job = new KIO::OpenUrlJob(QUrl::fromLocalFile(fileName), this);
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+                job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#else
                 job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#endif
                 job->setDeleteTemporaryFile(true);
                 job->start();
             }
@@ -604,6 +682,8 @@ void RuqolaMainWindow::slotLoginPageActivated(bool loginPageActivated)
     mDirectory->setEnabled(!loginPageActivated);
     mNextUnreadChannel->setEnabled(!loginPageActivated);
     mShowLog->setEnabled(!loginPageActivated);
+    mShowRocketChatServerInfo->setVisible(!loginPageActivated && hasBannerInfo());
+    mRoomAvatar->setEnabled(!loginPageActivated);
 }
 
 void RuqolaMainWindow::slotConfigureNotifications()
@@ -639,11 +719,18 @@ void RuqolaMainWindow::slotAdministrator()
     dlg.exec();
 }
 
+void RuqolaMainWindow::slotAdministratorServerSettings()
+{
+    AdministratorSettingsDialog dlg(mCurrentRocketChatAccount, this);
+    dlg.loadSettings();
+    dlg.exec();
+}
+
 void RuqolaMainWindow::slotDirectory()
 {
-    DirectoryDialog dlg(mCurrentRocketChatAccount, this);
-    dlg.fillTabs();
-    dlg.exec();
+    auto dlg = new DirectoryDialog(mCurrentRocketChatAccount, this);
+    dlg->fillTabs();
+    dlg->show();
 }
 
 bool RuqolaMainWindow::queryClose()
@@ -766,3 +853,49 @@ void RuqolaMainWindow::updateHamburgerMenu()
     menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))));
     mHamburgerMenu->setMenu(menu);
 }
+
+void RuqolaMainWindow::slotFullScreen(bool t)
+{
+    KToggleFullScreenAction::setFullScreen(this, t);
+    QMenuBar *mb = menuBar();
+    if (t) {
+        auto b = new QToolButton(mb);
+        b->setDefaultAction(mShowFullScreenAction);
+        b->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Ignored));
+        b->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
+        mb->setCornerWidget(b, Qt::TopRightCorner);
+        b->setVisible(true);
+        b->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    } else {
+        QWidget *w = mb->cornerWidget(Qt::TopRightCorner);
+        if (w) {
+            w->deleteLater();
+        }
+    }
+}
+
+void RuqolaMainWindow::slotShowNotifyMessage(const QString &accountName, const QString &messageId, const QString &roomId)
+{
+    Ruqola::self()->setCurrentAccount(accountName);
+    Q_EMIT mCurrentRocketChatAccount->selectRoomByRoomIdRequested(roomId);
+    // TODO use messageId too
+}
+
+void RuqolaMainWindow::slotOpenNotificationHistory()
+{
+    mNotificationToolButton->hide();
+    NotificationHistoryDialog dlg(this);
+    connect(&dlg, &NotificationHistoryDialog::showNotifyMessage, this, &RuqolaMainWindow::slotShowNotifyMessage);
+    dlg.exec();
+}
+
+void RuqolaMainWindow::slotRocketChatInformation()
+{
+    BannerInfoDialog dlg(mCurrentRocketChatAccount, this);
+    dlg.exec();
+}
+
+void RuqolaMainWindow::slotShowRoomAvatar(bool checked)
+{
+    mCurrentRocketChatAccount->setShowRoomAvatar(checked);
+}
